A high-performance Vulkan driver with automated resource management and
execution. Start with Graph — bind resources, record commands, and submit for execution.
- Beginner:
Graph,cmd,node,pool— the high-level graph API - Intermediate:
driver— smart-pointer Vulkan wrappers (resources, pipelines, device) - Expert:
driverre-exportsashandvk_sync— raw Vulkan bindings
For installation, guides, and examples see the Guide Book.
Modules
- cmd
- Strongly-typed
Graphcommands. - driver
- ADVANCED: Raw Vulkan wrappers. Most users should use
Graph,cmd, andnodeinstead. - node
- Handles for Vulkan smart-pointer resources.
- pool
- Resource pooling, requesting, and caching types.
- stream
- Reusable command streams.
- submission
- Submission and recording types.
Macros
Structs
- Command
Execution - Tracks whether a graph command has completed device execution.
- Command
Execution Abandoned - Error returned when a tracked command execution can no longer complete.
- Graph
- A composable graph of Vulkan command buffer operations.
- Graph
Builder - Builder for incrementally constructing a
Graph. - LazyStr
- Lazily formats string arguments on first string access.
- Timestamp
Query - Identifies a timestamp query written by
Graph::write_timestamp,cmd::Command::write_timestamp, orcmd::PipelineCommand::write_timestamp.
Enums
- LoadOp
- Specifies the state of a color or combined depth and stencil attachment image during graphics render pass framebuffer load operations.
- StoreOp
- Specifies the state of a color or combined depth and stencil attachment image after graphics render pass framebuffer store operations.