Module cmd

Module cmd 

Strongly-typed Graph commands.

Structs

Binding
Describes the SPIR-V binding index, and optionally a specific descriptor set and array index.
BuildAccelerationStructureIndirectInfo
Specifies the information and data used to build an acceleration structure with some parameters sourced on the device.
BuildAccelerationStructureInfo
Specifies the information and data used to build an acceleration structure.
Command
A general-purpose Vulkan command which may contain acceleration structure operations, transfers, or shader pipelines.
CommandRef
Recording interface for general Vulkan commands.
ComputeCommandRef
Recording interface for computing commands.
GraphicCommandRef
Recording interface for drawing commands.
PipelineCommand
A Command which has been bound to a particular compute, graphic, or ray-trace pipeline.
RayTraceCommandRef
Recording interface for ray tracing commands.
UpdateAccelerationStructureIndirectInfo
Specifies the information and data used to update an acceleration structure with some parameters sourced on the device.
UpdateAccelerationStructureInfo
Specifies the information and data used to update an acceleration structure.

Enums

ClearColorValue
Structure specifying a clear color value.
LoadOp
Specifies the state of a color or combined depth and stencil attachment image during graphic render pass framebuffer load operations.
StoreOp
Specifies the state of a color or combined depth and stencil attachment image after graphic render pass framebuffer store operations.

Traits

Pipeline
A trait for pipelines which may be bound to a Command.
Subresource
Allows for a resource to be reinterpreted as differently formatted data.