ClearColorValue

Enum ClearColorValue 

pub enum ClearColorValue {
    Float32([f32; 4]),
    Int32([i32; 4]),
    Uint32([u32; 4]),
}
Structure specifying a clear color value.

Variants



Float32([f32; 4])

Value as f32.

Use this member for color clear values when the format of the image or attachment is one of the numeric formats with a numeric type that is floating-point. Floating-point values are automatically converted to the format of the image, with the clear value being treated as linear if the image is sRGB.



Int32([i32; 4])

Value as i32.

Use this member for color clear values when the format of the image or attachment has a numeric type that is signed integer. Signed integer values are converted to the format of the image by casting to the smaller type (with negative 32-bit values mapping to negative values in the smaller type). If the integer clear value is not representable in the target type (e.g. would overflow in conversion to that type), the clear value is undefined.



Uint32([u32; 4])

Value as u32.

Use this member for color clear values when the format of the image or attachment has a numeric type that is unsigned integer. Unsigned integer values are converted to the format of the image by casting to the integer type with fewer bits.

Implementations

Source

impl ClearColorValue

pub const BLACK_ALPHA_ONE: Self

RGB zeros and alpha ones.

pub const BLACK_ALPHA_ZERO: Self

All zeros.

pub const WHITE_ALPHA_ONE: Self

RGB zeros and alpha ones.

pub const WHITE_ALPHA_ZERO: Self

RGB ones and alpha zeros.

pub const fn rgba(r: f32, g: f32, b: f32, a: f32) -> Self

Convenience constructor for clear color values.

pub const fn from_f32(r: f32, g: f32, b: f32, a: f32) -> Self

Convert RGB+A values into a ClearColorValue.

pub const fn from_u8(r: u8, g: u8, b: u8, a: u8) -> Self

Convert RGB+A values into a ClearColorValue.