LoadOp

Enum LoadOp 

pub enum LoadOp<T> {
    Clear(T),
    DontCare,
    Load,
}
Specifies the state of a color or combined depth and stencil attachment image during graphic render pass framebuffer load operations.

Use this to specify the desired contents of any image before use in a pipeline command buffer.

Variants



Clear(T)

Clears the attachment.

T will be ClearColorValue for color images or vk::ClearDepthStencilValue for combined depth and stencil images.



DontCare

The attachment will become undefined and reads will produce garbage data.



Load

The attachment will be preserved in memory.

Implementations

Source

impl LoadOp<ClearColorValue>

pub const CLEAR_BLACK_ALPHA_ONE: Self

A load operation which results in a color attachment filled with rgb zeros and alpha ones.

pub const CLEAR_BLACK_ALPHA_ZERO: Self

A load operation which results in a color attachment filled with zeros.

pub const CLEAR_WHITE_ALPHA_ONE: Self

A load operation which results in a color attachment filled with rgb zeros and alpha ones.

pub const CLEAR_WHITE_ALPHA_ZERO: Self

A load operation which results in a color attachment filled with rgb ones and alpha zeros.

pub fn clear_rgba(r: f32, g: f32, b: f32, a: f32) -> Self

Convenience constructor for clear color values.

Source

impl LoadOp<ClearDepthStencilValue>

pub const CLEAR_ONE_STENCIL_ZERO: Self

A load operation which results in a depth attachment filled with ones and stencil filled with zeros.

pub const CLEAR_ZERO_STENCIL_ZERO: Self

A load operation which results in a depth and stencil attachment filled with zeros.

pub fn clear_depth_stencil(depth: f32, stencil: u32) -> Self

Convenience constructor for clear depth and stencil values.