pub enum StoreOp {
DontCare,
Store,
}Expand description
Specifies the state of a color or combined depth and stencil attachment image after graphic render pass framebuffer store operations.
Use this to specify the desired contents of any image after use in a pipeline command buffer.
Variants
DontCare
The attachment will become undefined and reads will produce garbage data.
Store
The attachment will be preserved in memory.