pub struct Binding {
pub binding: u32,
pub offset: u32,
pub set: u32,
}Expand description
Describes the SPIR-V binding index, and optionally a specific descriptor set and array index.
Generally you might pass a function a descriptor using a simple integer:
let descriptor = 42;
my_func(descriptor, image);But also:
(0, 42)for descriptor set0and binding index42(42, [8])for the same binding, but the 8th element(0, 42, [8])same as the previous example
Fields
binding: u32The value of the descriptor binding decoration applied to the variable.
offset: u32An array-element offset applied to this descriptor.
set: u32An optional descriptor set index value.