pub struct BuildAccelerationStructureIndirectInfo {
pub accel_struct: AnyAccelerationStructureNode,
pub build_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>,
pub range_base: DeviceAddress,
pub range_stride: u32,
pub scratch_data: DeviceOrHostAddress,
}Expand description
Specifies the information and data used to build an acceleration structure with some parameters sourced on the device.
Fields
accel_struct: AnyAccelerationStructureNodeThe acceleration structure to be written.
build_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>Specifies the geometry data to use when building the acceleration structure.
range_base: DeviceAddressA buffer device addresses which points to data.geometry.len()
vk::AccelerationStructureBuildRangeInfoKHR structures defining dynamic offsets to the
addresses where geometry data is stored.
range_stride: u32Byte stride between elements of Self::range_base.
scratch_data: DeviceOrHostAddressThe temporary buffer or host address (with enough capacity per
AccelerationStructure::size_of).
Implementations
Sourceimpl BuildAccelerationStructureIndirectInfo
impl BuildAccelerationStructureIndirectInfo
Sourcepub fn new(
accel_struct: impl Into<AnyAccelerationStructureNode>,
scratch_data: impl Into<DeviceOrHostAddress>,
build_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>,
range_base: DeviceAddress,
range_stride: u32,
) -> Self
pub fn new( accel_struct: impl Into<AnyAccelerationStructureNode>, scratch_data: impl Into<DeviceOrHostAddress>, build_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>, range_base: DeviceAddress, range_stride: u32, ) -> Self
Constructs new acceleration structure indirect build information.