pub struct BuildAccelerationStructureInfo {
pub accel_struct: AnyAccelerationStructureNode,
pub build_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>,
pub scratch_addr: DeviceOrHostAddress,
}Expand description
Specifies the information and data used to build an acceleration structure.
Fields
accel_struct: AnyAccelerationStructureNodeThe acceleration structure to be written.
build_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>Specifies the geometry data to use when building the acceleration structure.
scratch_addr: DeviceOrHostAddressThe temporary buffer or host address (with enough capacity per
AccelerationStructure::size_of).
Implementations
Sourceimpl BuildAccelerationStructureInfo
impl BuildAccelerationStructureInfo
Sourcepub fn new(
accel_struct: impl Into<AnyAccelerationStructureNode>,
scratch_addr: impl Into<DeviceOrHostAddress>,
build_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>,
) -> Self
pub fn new( accel_struct: impl Into<AnyAccelerationStructureNode>, scratch_addr: impl Into<DeviceOrHostAddress>, build_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>, ) -> Self
Constructs new acceleration structure build information.