pub struct CommandBuilder<'a> { /* private fields */ }Expand description
Builder for incrementally constructing a Command.
Implementations
Sourceimpl<'a> CommandBuilder<'a>
impl<'a> CommandBuilder<'a>
Sourcepub fn push_cmd(self) -> &'a mut Graph
pub fn push_cmd(self) -> &'a mut Graph
Pushes the command onto its graph and returns the graph.
Sourcepub fn blit_image(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyImageNode>,
filter: Filter,
regions: impl AsRef<[ImageBlit]> + 'static + Send,
) -> Self
pub fn blit_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, filter: Filter, regions: impl AsRef<[ImageBlit]> + 'static + Send, ) -> Self
Blits image regions.
Sourcepub fn clear_color_image(
self,
image: impl Into<AnyImageNode>,
color: impl Into<ClearColorValue>,
) -> Self
pub fn clear_color_image( self, image: impl Into<AnyImageNode>, color: impl Into<ClearColorValue>, ) -> Self
Clears a color image.
Sourcepub fn clear_depth_stencil_image(
self,
image: impl Into<AnyImageNode>,
depth: f32,
stencil: u32,
) -> Self
pub fn clear_depth_stencil_image( self, image: impl Into<AnyImageNode>, depth: f32, stencil: u32, ) -> Self
Clears a depth/stencil image.
Sourcepub fn copy_buffer(
self,
src: impl Into<AnyBufferNode>,
dst: impl Into<AnyBufferNode>,
regions: impl AsRef<[BufferCopy]> + 'static + Send,
) -> Self
pub fn copy_buffer( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyBufferNode>, regions: impl AsRef<[BufferCopy]> + 'static + Send, ) -> Self
Copies data between buffer regions.
Sourcepub fn copy_buffer_to_image(
self,
src: impl Into<AnyBufferNode>,
dst: impl Into<AnyImageNode>,
regions: impl AsRef<[BufferImageCopy]> + 'static + Send,
) -> Self
pub fn copy_buffer_to_image( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyImageNode>, regions: impl AsRef<[BufferImageCopy]> + 'static + Send, ) -> Self
Copies data from a buffer into image regions.
Sourcepub fn copy_image(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyImageNode>,
regions: impl AsRef<[ImageCopy]> + 'static + Send,
) -> Self
pub fn copy_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, regions: impl AsRef<[ImageCopy]> + 'static + Send, ) -> Self
Copies data between image regions.
Sourcepub fn copy_image_to_buffer(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyBufferNode>,
regions: impl AsRef<[BufferImageCopy]> + 'static + Send,
) -> Self
pub fn copy_image_to_buffer( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyBufferNode>, regions: impl AsRef<[BufferImageCopy]> + 'static + Send, ) -> Self
Copies image region data into a buffer.
Sourcepub fn fill_buffer(
self,
buffer: impl Into<AnyBufferNode>,
region: Range<DeviceSize>,
data: u32,
) -> Self
pub fn fill_buffer( self, buffer: impl Into<AnyBufferNode>, region: Range<DeviceSize>, data: u32, ) -> Self
Fills a region of a buffer with a fixed value.
Sourcepub fn update_buffer(
self,
buffer: impl Into<AnyBufferNode>,
offset: DeviceSize,
data: impl AsRef<[u8]> + 'static + Send,
) -> Self
pub fn update_buffer( self, buffer: impl Into<AnyBufferNode>, offset: DeviceSize, data: impl AsRef<[u8]> + 'static + Send, ) -> Self
Records a vkCmdUpdateBuffer command.