RayTraceCommandRef

Struct RayTraceCommandRef 

pub struct RayTraceCommandRef<'a> { /* private fields */ }
Recording interface for ray tracing commands.

This structure provides a strongly-typed set of methods which allow ray trace shader code to be executed. An instance is provided to the closure argument of PipelineCommand::record_cmd which may be accessed by binding a RayTracePipeline to a command.

Examples

Basic usage:

my_graph.begin_cmd()
        .debug_name("my ray trace command")
        .bind_pipeline(&my_ray_trace_pipeline)
        .record_cmd(move |cmd| {
            // During this closure we have access to the ray trace functions!
        });

Implementations

Source

impl RayTraceCommandRef<'_>

pub fn push_constants(&self, offset: u32, data: &[u8]) -> &Self

Updates push constants.

Push constants represent a high speed path to modify constant data in pipelines that is expected to outperform memory-backed resource updates.

Push constant values can be updated incrementally, causing shader stages to read the new data for push constants modified by this command, while still reading the previous data for push constants not modified by this command.

Device limitations

See device.physical_device.props.limits.max_push_constants_size for the limits of the current device. You may also check [gpuinfo.org] for a listing of reported limits on other devices.

Examples

Basic usage:

#version 460
#pragma shader_stage(closest)

layout(push_constant) uniform PushConstants {
    layout(offset = 0) uint some_val;
} push_constants;

void main() {
    // TODO: Add bindings to write things!
}
my_graph.begin_cmd()
        .debug_name("draw a cornell box")
        .bind_pipeline(&my_ray_trace_pipeline)
        .record_cmd(move |cmd| {
            cmd.push_constants(0, &[0xcb])
                   .trace_rays(&rgen_sbt, &hit_sbt, &miss_sbt, &call_sbt, 320, 200, 1);
        });

See vkCmdPushConstants.

pub fn set_stack_size(&self, pipeline_stack_size: u32) -> &Self

Set the stack size dynamically for a ray trace pipeline.

See RayTracePipelineInfo::dynamic_stack_size and see the Vulkan spec.

pub fn trace_rays( &self, raygen_shader_binding_table: &StridedDeviceAddressRegionKHR, miss_shader_binding_table: &StridedDeviceAddressRegionKHR, hit_shader_binding_table: &StridedDeviceAddressRegionKHR, callable_shader_binding_table: &StridedDeviceAddressRegionKHR, width: u32, height: u32, depth: u32, ) -> &Self

Ray traces using the currently-bound RayTracePipeline and the given shader binding tables.

Shader binding tables must be constructed according to this example.

Examples

Basic usage:

my_graph.begin_cmd()
        .debug_name("draw a cornell box")
        .bind_pipeline(&my_ray_trace_pipeline)
        .record_cmd(move |cmd| {
            cmd.trace_rays(&rgen_sbt, &hit_sbt, &miss_sbt, &call_sbt, 320, 200, 1);
        });
pub fn trace_rays_indirect( &self, raygen_shader_binding_table: &StridedDeviceAddressRegionKHR, miss_shader_binding_table: &StridedDeviceAddressRegionKHR, hit_shader_binding_table: &StridedDeviceAddressRegionKHR, callable_shader_binding_table: &StridedDeviceAddressRegionKHR, indirect_device_address: DeviceAddress, ) -> &Self

Ray traces using the currently-bound RayTracePipeline and the given shader binding tables.

indirect_device_address is a buffer device address which is a pointer to a vk::TraceRaysIndirectCommandKHR structure containing the trace ray parameters.

See vkCmdTraceRaysIndirectKHR.

Methods from Deref<Target = CommandRef<'a>>

pub fn build_accel_struct( &self, infos: &[BuildAccelerationStructureInfo], ) -> &Self

Build acceleration structures.

There is no ordering or synchronization implied between any of the individual acceleration structure builds.

Requires a scratch buffer which was created with the following requirements:

  • Flags must include vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS
  • Size must be equal to or greater than the build_size value returned by AccelerationStructure::size_of, aligned to min_accel_struct_scratch_offset_alignment of PhysicalDevice::accel_struct_properties.
Examples

Basic usage:

my_graph.begin_cmd()
        .resource_access(index_buf, AccessType::IndexBuffer)
        .resource_access(vertex_buf, AccessType::VertexBuffer)
        .resource_access(scratch_buf, AccessType::AccelerationStructureBufferWrite)
        .resource_access(blas_node, AccessType::AccelerationStructureBuildWrite)
        .record_cmd(move |cmd| {
            let scratch_addr = cmd.resource(scratch_buf).device_address();
            let geom = AccelerationStructureGeometry {
                max_primitive_count: 64,
                flags: vk::GeometryFlagsKHR::OPAQUE,
                geometry: AccelerationStructureGeometryData::Triangles {
                    index_addr: DeviceOrHostAddress::DeviceAddress(
                        cmd.resource(index_buf).device_address()
                    ),
                    index_type: vk::IndexType::UINT32,
                    max_vertex: 42,
                    transform_addr: None,
                    vertex_addr: DeviceOrHostAddress::DeviceAddress(
                        cmd.resource(vertex_buf).device_address(),
                    ),
                    vertex_format: vk::Format::R32G32B32_SFLOAT,
                    vertex_stride: 12,
                },
            };
            let build_range = vk::AccelerationStructureBuildRangeInfoKHR {
                first_vertex: 0,
                primitive_count: 1,
                primitive_offset: 0,
                transform_offset: 0,
            };
            let info = AccelerationStructureGeometryInfo::blas([(geom, build_range)]);

            cmd.build_accel_struct(&[
                BuildAccelerationStructureInfo::new(blas_node, scratch_addr, info)
            ]);
        });

See also:

pub fn build_accel_struct_indirect( &self, infos: &[BuildAccelerationStructureIndirectInfo], ) -> &Self

Builds acceleration structures with some parameters provided on the device.

There is no ordering or synchronization implied between any of the individual acceleration structure builds.

Each BuildAccelerationStructureIndirectInfo::range_base is a buffer device address which points to an array of vk::AccelerationStructureBuildRangeInfoKHR structures defining dynamic offsets to the addresses where geometry data is stored.

pub fn update_accel_struct( &self, infos: &[UpdateAccelerationStructureInfo], ) -> &Self

Update acceleration structures.

There is no ordering or synchronization implied between any of the individual acceleration structure updates.

Requires a scratch buffer which was created with the following requirements:

  • Flags must include vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS
  • Size must be equal to or greater than the update_size value returned by AccelerationStructure::size_of, aligned to min_accel_struct_scratch_offset_alignment of PhysicalDevice::accel_struct_properties.
pub fn update_accel_struct_indirect( &self, infos: &[UpdateAccelerationStructureIndirectInfo], ) -> &Self

Updates acceleration structures with some parameters provided on the device.

There is no ordering or synchronization implied between any of the individual acceleration structure updates.

Each UpdateAccelerationStructureIndirectInfo::range_base is a buffer device address which points to an array of vk::AccelerationStructureBuildRangeInfoKHR structures defining dynamic offsets to the addresses where geometry data is stored.

pub fn resource<N>(&self, resource_node: N) -> &N::Resource
where N: Node,

Returns a borrow of the original Vulkan resource (buffer, image or acceleration structure) which the given bound resource node represents.

Methods from Deref<Target = CommandBuffer>

pub fn has_executed(&self) -> Result<bool, DriverError>

Returns true after the GPU has executed the previous submission to this command buffer.

See Self::wait_until_executed to block while checking.