pub struct UpdateAccelerationStructureIndirectInfo {
pub dst_accel_struct: AnyAccelerationStructureNode,
pub range_base: DeviceAddress,
pub range_stride: u32,
pub scratch_addr: DeviceOrHostAddress,
pub src_accel_struct: AnyAccelerationStructureNode,
pub update_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>,
}Expand description
Specifies the information and data used to update an acceleration structure with some parameters sourced on the device.
Fields
dst_accel_struct: AnyAccelerationStructureNodeThe acceleration structure to be written.
range_base: DeviceAddressA buffer device addresses which points to data.geometry.len()
vk::AccelerationStructureBuildRangeInfoKHR structures defining dynamic offsets to the
addresses where geometry data is stored.
range_stride: u32Byte stride between elements of Self::range_base.
scratch_addr: DeviceOrHostAddressThe temporary buffer or host address (with enough capacity per
AccelerationStructure::size_of).
src_accel_struct: AnyAccelerationStructureNodeThe source acceleration structure to be read.
update_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>Specifies the geometry data to use when building the acceleration structure.
Implementations
Sourceimpl UpdateAccelerationStructureIndirectInfo
impl UpdateAccelerationStructureIndirectInfo
Sourcepub fn new(
src_accel_struct: impl Into<AnyAccelerationStructureNode>,
dst_accel_struct: impl Into<AnyAccelerationStructureNode>,
scratch_addr: impl Into<DeviceOrHostAddress>,
update_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>,
range_base: DeviceAddress,
range_stride: u32,
) -> Self
pub fn new( src_accel_struct: impl Into<AnyAccelerationStructureNode>, dst_accel_struct: impl Into<AnyAccelerationStructureNode>, scratch_addr: impl Into<DeviceOrHostAddress>, update_data: AccelerationStructureGeometryInfo<AccelerationStructureGeometry>, range_base: DeviceAddress, range_stride: u32, ) -> Self
Constructs new acceleration structure indirect update information.