pub struct UpdateAccelerationStructureInfo {
pub dst_accel_struct: AnyAccelerationStructureNode,
pub scratch_addr: DeviceOrHostAddress,
pub src_accel_struct: AnyAccelerationStructureNode,
pub update_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>,
}Expand description
Specifies the information and data used to update an acceleration structure.
Fields
dst_accel_struct: AnyAccelerationStructureNodeThe acceleration structure to be written.
scratch_addr: DeviceOrHostAddressThe temporary buffer or host address (with enough capacity per
AccelerationStructure::size_of).
src_accel_struct: AnyAccelerationStructureNodeThe source acceleration structure to be read.
update_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>Specifies the geometry data to use when updating the acceleration structure.
Implementations
Sourceimpl UpdateAccelerationStructureInfo
impl UpdateAccelerationStructureInfo
Sourcepub fn new(
src_accel_struct: impl Into<AnyAccelerationStructureNode>,
dst_accel_struct: impl Into<AnyAccelerationStructureNode>,
scratch_addr: impl Into<DeviceOrHostAddress>,
update_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>,
) -> Self
pub fn new( src_accel_struct: impl Into<AnyAccelerationStructureNode>, dst_accel_struct: impl Into<AnyAccelerationStructureNode>, scratch_addr: impl Into<DeviceOrHostAddress>, update_data: AccelerationStructureGeometryInfo<(AccelerationStructureGeometry, AccelerationStructureBuildRangeInfoKHR)>, ) -> Self
Constructs new acceleration structure update information.