Subresource

Trait Subresource 

pub trait Subresource {
    type Info;
    type Range;
}
Allows for a resource to be reinterpreted as differently formatted data.

Required Associated Types

type Info

The information about the subresource when bound directly to shader descriptors.

type Range

The information about the subresource when used indirectly by any part of a graph.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors