ADVANCED: Raw Vulkan wrappers. Most users should use Graph,
cmd, and node instead.
Resources
Resources are created and destroyed using RAII-style wrapper structures.
The following resources are available:
Graph-tracked resources are logically mutable and contain useful read-only public fields, for example:
Buffer field | Type |
|---|---|
device | Device |
handle | vk::Buffer |
info | BufferInfo |
DescriptorSet is instead a shared immutable wrapper and
exposes the same information through device(), handle(), and info() methods.
Graph-tracked resources use atomic AccessType values to maintain
consistency and track changes. Descriptor contents do not declare graph synchronization.
Pipelines
Pipelines enable reading and writing resources using shader code running on physical graphics hardware.
The following pipelines are available:
Pipelines are immutable. All pipeline types contain useful public methods, for example:
Modules
- accel_
struct - Acceleration structure resource types
- buffer
- Buffer resource types
- cmd_buf
- Command buffer types
- compute
- Compute pipeline types.
- descriptor_
set - Explicit descriptor set allocation and update support.
- device
- Logical device types
- fence
- Fence types.
- graphics
- Graphics pipeline types
- image
- Image resource types
- instance
- Vulkan initialization types.
- physical_
device - Physical device types.
- ray_
tracing - Ray tracing pipeline types
- render_
pass - Render pass related types.
- shader
- Shader reflection and pipeline-stage descriptions.
- surface
- Native platform window surface types.
- swapchain
- Native window presentation types.
Enums
- Driver
Error - Describes the general category of all graphics driver failure cases.
Functions
- format_
texel_ block_ extent - Returns the extent of a block of texels for the given Vulkan format.
Uncompressed formats typically have a block extent of
(1, 1). - format_
texel_ block_ size - Returns number of bytes used to store one texel block (a single addressable element of an uncompressed image, or a single compressed block of a compressed image).