AccelerationStructure

Struct AccelerationStructure 

pub struct AccelerationStructure {
    pub buffer: Buffer,
    pub handle: AccelerationStructureKHR,
    pub info: AccelerationStructureInfo,
    pub name: Option<String>,
    /* private fields */
}
Smart pointer handle to an [acceleration structure] object.

Also contains the backing buffer and information about the object.

let info = AccelerationStructureInfo::blas(0);
let accel_struct = AccelerationStructure::create(&device, info)?;
let addr = accel_struct.device_address();

assert_eq!(accel_struct.info, info);
assert_ne!(accel_struct.handle, vk::AccelerationStructureKHR::null());

See VkAccelerationStructureKHR.

Fields

buffer: Buffer

The native Vulkan resource handle of the buffer which supports this acceleration structure.

Note: This field is read-only.

handle: AccelerationStructureKHR

The native Vulkan resource handle of this acceleration structure.

Note: This field is read-only.

info: AccelerationStructureInfo

Information used to create this object.

Note: This field is read-only.

name: Option<String>

A name for debugging purposes.

Implementations

Source

impl AccelerationStructure

pub fn create( device: &Device, info: impl Into<AccelerationStructureInfo>, ) -> Result<Self, DriverError>

Creates a new acceleration structure on the given device.

Examples

Basic usage:

const SIZE: vk::DeviceSize = 1024;
let info = AccelerationStructureInfo::blas(SIZE);
let accel_struct = AccelerationStructure::create(&device, info)?;

assert_ne!(accel_struct.handle, vk::AccelerationStructureKHR::null());
assert_eq!(accel_struct.info.size, SIZE);
pub fn access(&self, next_access: AccessType) -> AccessType

Keeps track of some next_access which affects this object.

Returns the previous access for which a pipeline barrier should be used to prevent data corruption.

Note

Used to maintain object state when passing a vk-graph-created vk::AccelerationStructureKHR handle to external code such as Ash or Erupt bindings.

Examples

Basic usage:

// Initially we want to "Build Write"
let next = AccessType::AccelerationStructureBuildWrite;
let prev = AccelerationStructure::access(&my_accel_struct, next);
assert_eq!(prev, AccessType::Nothing);

// External code may now "Build Write"; no barrier required

// Subsequently we want to "Build Read"
let next = AccessType::AccelerationStructureBuildRead;
let prev = AccelerationStructure::access(&my_accel_struct, next);
assert_eq!(prev, AccessType::AccelerationStructureBuildWrite);

// A barrier on "Build Write" before "Build Read" is required!
pub fn debug_name(self, name: impl Into<String>) -> Self

Sets the debugging name assigned to this acceleration structure.

pub fn device_address(&self) -> DeviceAddress

Returns the device address of this object.

Examples

Basic usage:

let addr = AccelerationStructure::device_address(&my_accel_struct);

assert_ne!(addr, 0);
pub fn instance_slice(instances: &[AccelerationStructureInstanceKHR]) -> &[u8]

Helper function which is used to prepare instance buffers.

pub fn size_of( device: &Device, info: &AccelerationStructureGeometryInfo<impl AsRef<AccelerationStructureGeometry>>, ) -> AccelerationStructureSize

Returns the size of some geometry info which is then used to create a new AccelerationStructure instance or update an existing instance.

Examples

Basic usage:

let my_geom = AccelerationStructureGeometry {
    max_primitive_count: 1,
    flags: vk::GeometryFlagsKHR::OPAQUE,
    geometry: my_geom_triangles,
};
let build_range = vk::AccelerationStructureBuildRangeInfoKHR {
    primitive_count: 1,
    primitive_offset: 0,
    first_vertex: 0,
    transform_offset: 0,
};
let my_info = AccelerationStructureGeometryInfo::blas([(my_geom, build_range)]);
let res = AccelerationStructure::size_of(&device, &my_info);

assert_eq!(res.create_size, 2432);
assert_eq!(res.build_size, 640);
assert_eq!(res.update_size, 0);