pub struct DeviceInfo {
pub debug: bool,
pub physical_device_index: usize,
}Expand description
Information used to create a Device instance.
Fields
debug: boolEnables the Vulkan validation layers.
This requires a Vulkan SDK installation and will panic when validation errors happen. See the LunarG Vulkan Validation Layers documentation for setup and behavior details.
When stderr is attached to an interactive terminal, validation errors will park the
callback thread for debugger attach.
NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will report an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.
Platform-specific
macOS: Has no effect unless the loaded feature is enabled.
physical_device_index: usizeIndex of the PhysicalDevice from the available devices. See
Instance::physical_devices.
Implementations
Sourceimpl DeviceInfo
impl DeviceInfo
Sourcepub fn builder() -> DeviceInfoBuilder
pub fn builder() -> DeviceInfoBuilder
Creates a default DeviceInfoBuilder.
Sourcepub fn into_builder(self) -> DeviceInfoBuilder
pub fn into_builder(self) -> DeviceInfoBuilder
Converts a DeviceInfo into a DeviceInfoBuilder.