DeviceInfoBuilder

Struct DeviceInfoBuilder 

pub struct DeviceInfoBuilder { /* private fields */ }
Builder for DeviceInfo.

Implementations

Source

impl DeviceInfoBuilder

pub fn debug(self, value: bool) -> Self

Enables the Vulkan validation layers.

This requires a Vulkan SDK installation and will panic when validation errors happen. See the LunarG Vulkan Validation Layers documentation for setup and behavior details.

When stderr is attached to an interactive terminal, validation errors will park the callback thread for debugger attach.

NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will report an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.

Platform-specific

macOS: Has no effect unless the loaded feature is enabled.

pub fn physical_device_index(self, value: usize) -> Self

Index of the PhysicalDevice from the available devices. See Instance::physical_devices.

Source

impl DeviceInfoBuilder

pub fn build(self) -> DeviceInfo

Builds a new DeviceInfo.