pub enum DriverError {
InvalidData,
Unsupported,
OutOfMemory,
}Expand description
Describes the general category of all graphics driver failure cases.
In the event of a failure you should follow the vk-graph code to the responsible Vulkan API
and then to the Ash stub call; it will generally contain a link to the appropriate
specification. The specifications provide a table of possible error conditions which can be a
good starting point to debug the issue.
Feel free to open an issue on GitHub, here for help debugging the issue.
Variants
InvalidData
The input data, or referenced data, is not valid for the current state.
Unsupported
The requested feature, or input configuration, is not supported for the current state.
OutOfMemory
The device has run out of physical memory.
Many drivers return this value for generic or unhandled error conditions.