BlendInfo

Struct BlendInfo 

pub struct BlendInfo {
    pub blend_enable: bool,
    pub src_color_blend_factor: BlendFactor,
    pub dst_color_blend_factor: BlendFactor,
    pub color_blend_op: BlendOp,
    pub src_alpha_blend_factor: BlendFactor,
    pub dst_alpha_blend_factor: BlendFactor,
    pub alpha_blend_op: BlendOp,
    pub color_write_mask: ColorComponentFlags,
}
Specifies color blend state used when rasterization is enabled for any color attachments accessed during rendering.

See VkPipelineColorBlendAttachmentState.

Fields

blend_enable: bool

Controls whether blending is enabled for the corresponding color attachment.

If blending is not enabled, the source fragment’s color for that attachment is passed through unmodified.

src_color_blend_factor: BlendFactor

Selects which blend factor is used to determine the source factors.

dst_color_blend_factor: BlendFactor

Selects which blend factor is used to determine the destination factors.

color_blend_op: BlendOp

Selects which blend operation is used to calculate the RGB values to write to the color attachment.

src_alpha_blend_factor: BlendFactor

Selects which blend factor is used to determine the source factor.

dst_alpha_blend_factor: BlendFactor

Selects which blend factor is used to determine the destination factor.

alpha_blend_op: BlendOp

Selects which blend operation is used to calculate the alpha values to write to the color attachment.

color_write_mask: ColorComponentFlags

A bitmask specifying which of the R, G, B, and/or A components are enabled for writing, as described for VkPipelineColorBlendAttachmentState.

Implementations

Source

impl BlendInfo

pub const ADDITIVE: Self

A commonly used blend mode for additive blending.

pub const REPLACE: Self

A commonly used blend mode for replacing color attachment values with new ones.

pub const ALPHA: Self

A commonly used blend mode for blending color attachment values based on the alpha channel.

pub const COLOR_WRITE_DISABLED: Self

A color attachment state that disables all color component writes.

This is useful for passes that bind a color attachment only to satisfy pipeline or render target layout requirements, while writing depth or stencil data without modifying color.

pub const PRE_MULTIPLIED_ALPHA: Self

A commonly used blend mode for blending color attachment values based on the alpha channel, where the color components have been pre-multiplied with the alpha component value.

pub fn builder() -> BlendInfoBuilder

Specifies a default blend mode which is not enabled.

pub fn into_builder(self) -> BlendInfoBuilder

Converts a BlendInfo into a BlendInfoBuilder.