DepthStencilInfo

Struct DepthStencilInfo 

pub struct DepthStencilInfo {
    pub back: StencilMode,
    pub bounds_test: bool,
    pub compare_op: CompareOp,
    pub depth_test: bool,
    pub depth_write: bool,
    pub front: StencilMode,
    pub min: OrderedFloat<f32>,
    pub max: OrderedFloat<f32>,
    pub stencil_test: bool,
}
Specifies the [depth bounds tests], [stencil test], and [depth test] pipeline state.

See VkPipelineDepthStencilStateCreateInfo.

Fields

back: StencilMode

Control parameters of the stencil test.

Defaults to StencilMode::IGNORE.

bounds_test: bool

Controls whether [depth bounds testing] is enabled.

See VkPipelineDepthStencilStateCreateInfo.

compare_op: CompareOp

A value specifying the comparison operator to use in the [depth comparison] step of the [depth test].

See VkPipelineDepthStencilStateCreateInfo.

Defaults to vk::CompareOp::NEVER.

depth_test: bool

Controls whether [depth testing] is enabled.

See VkPipelineDepthStencilStateCreateInfo.

depth_write: bool

Controls whether [depth writes] are enabled when depth_test is true.

Depth writes are always disabled when depth_test is false.

See VkPipelineDepthStencilStateCreateInfo.

front: StencilMode

Control parameters of the stencil test.

Defaults to StencilMode::IGNORE.

min: OrderedFloat<f32>

Minimum depth bound used in the [depth bounds test].

See VkPipelineDepthStencilStateCreateInfo.

max: OrderedFloat<f32>

Maximum depth bound used in the [depth bounds test].

See VkPipelineDepthStencilStateCreateInfo.

stencil_test: bool

Controls whether [stencil testing] is enabled.

See VkPipelineDepthStencilStateCreateInfo.

Implementations

Source

impl DepthStencilInfo

pub const IGNORE: Self

Specifies a no-depth/no-stencil mode.

This is the default state.

pub const DEPTH_WRITE_LESS: Self

Common depth-write mode for normal-Z depth buffers.

pub const DEPTH_WRITE_LESS_OR_EQUAL: Self

Common depth-write mode for normal-Z depth buffers when equal depth passes are accepted.

pub const DEPTH_WRITE_GREATER: Self

Common depth-write mode for reversed-Z depth buffers.

pub const DEPTH_WRITE_GREATER_OR_EQUAL: Self

Common depth-write mode for reversed-Z depth buffers when equal depth passes are accepted.

pub const DEPTH_WRITE_LESS_IGNORE_STENCIL: Self = Self::DEPTH_WRITE_LESS

A commonly used normal-Z depth-write mode with stencil ignored.

pub const fn depth_read(compare_op: CompareOp) -> Self

Creates a depth-read mode with stencil ignored.

pub const fn depth_write(compare_op: CompareOp) -> Self

Creates a depth-write mode with stencil ignored.

pub const fn depth_read_write(compare_op: CompareOp) -> Self

Creates a depth-read/write mode with stencil ignored.

pub fn builder() -> DepthStencilInfoBuilder

Creates a default DepthStencilInfoBuilder.

pub fn into_builder(self) -> DepthStencilInfoBuilder

Converts a DepthStencilInfo into a DepthStencilInfoBuilder.