GraphicsPipelineInfo

Struct GraphicsPipelineInfo 

pub struct GraphicsPipelineInfo {
    pub alpha_to_coverage: bool,
    pub alpha_to_one: bool,
    pub bindless_descriptor_count: u32,
    pub blend: BlendInfo,
    pub cull_mode: CullModeFlags,
    pub front_face: FrontFace,
    pub min_sample_shading: Option<OrderedFloat<f32>>,
    pub polygon_mode: PolygonMode,
    pub topology: PrimitiveTopology,
    pub samples: SampleCount,
}
Information used to create a GraphicsPipeline instance.

See VkGraphicsPipelineCreateInfo.

Fields

alpha_to_coverage: bool

Controls whether a temporary coverage value is generated based on the alpha component of the fragment’s first color output.

alpha_to_one: bool

Controls whether the alpha component of the fragment’s first color output is replaced with one.

bindless_descriptor_count: u32

The number of descriptors to allocate for a given binding when using bindless (unbounded) syntax.

The default is 8192.

Examples

Basic usage (GLSL):

#version 460 core
#extension GL_EXT_nonuniform_qualifier : require
#pragma shader_stage(fragment)

layout(set = 0, binding = 0) uniform sampler2D my_binding[];

void main() {
    // my_binding will have space for 8,192 images by default
}
blend: BlendInfo

Specifies color blend state used when rasterization is enabled for any color attachments accessed during rendering.

The default value is BlendInfo::REPLACE.

cull_mode: CullModeFlags

Bitmask controlling triangle culling.

The default value is vk::CullModeFlags::BACK.

front_face: FrontFace

Interprets polygon front-facing orientation.

The default value is vk::FrontFace::COUNTER_CLOCKWISE.

min_sample_shading: Option<OrderedFloat<f32>>

Specifies a fraction of the minimum number of unique samples to process for each fragment.

polygon_mode: PolygonMode

Controls polygon rasterization mode.

The default value is vk::PolygonMode::FILL.

topology: PrimitiveTopology

Input primitive topology.

The default value is vk::PrimitiveTopology::TRIANGLE_LIST.

samples: SampleCount

Multisampling antialias mode.

The default value is SampleCount::Type1.

See VkPipelineMultisampleStateCreateInfo.

Implementations

Source

impl GraphicsPipelineInfo

pub fn builder() -> GraphicsPipelineInfoBuilder

Creates a default GraphicsPipelineInfoBuilder.

pub fn into_builder(self) -> GraphicsPipelineInfoBuilder

Converts a GraphicsPipelineInfo into a GraphicsPipelineInfoBuilder.