ImageInfoBuilder

Struct ImageInfoBuilder 

pub struct ImageInfoBuilder { /* private fields */ }
Builder for ImageInfo.

Implementations

Source

impl ImageInfoBuilder

pub fn alloc_dedicated(self, value: bool) -> Self

Specifies a dedicated memory allocation managed by the Vulkan driver and not by the internal memory allocation pool transient resources share.

The driver may optimize access to dedicated images.

pub fn array_layer_count(self, value: u32) -> Self

The number of layers in the image.

pub fn depth(self, value: u32) -> Self

Image extent of the Z axis, when describing a three dimensional image.

pub fn flags(self, value: ImageCreateFlags) -> Self

A bitmask describing additional parameters of the image.

See VkImageCreateFlagBits.

pub fn format(self, value: Format) -> Self

The format and type of the texel blocks that will be contained in the image.

pub fn height(self, value: u32) -> Self

Image extent of the Y axis, when describing a two or three dimensional image.

pub fn host_readable(self, value: bool) -> Self

Specifies an image whose memory is host-visible and may be mapped for reads.

Memory optimal for CPU readback of data may be used.

pub fn host_writable(self, value: bool) -> Self

Specifies an image whose memory is host-visible and may be mapped for writes.

Memory optimal for uploading data to the GPU may be used.

pub fn mip_level_count(self, value: u32) -> Self

The number of levels of detail available for minified sampling of the image.

pub fn sample_count(self, value: SampleCount) -> Self

Specifies the number of [samples per texel].

See VkImageCreateInfo.

pub fn sharing_mode(self, value: SharingMode) -> Self

Controls whether the image is accessible from a single queue family (EXCLUSIVE) or from multiple queue families concurrently (CONCURRENT).

EXCLUSIVE (the default) restricts the image to a single queue family. This may enable driver optimizations but requires ownership transfers to use the image on a different queue family.

Set to CONCURRENT when the image will be accessed from multiple queue families (e.g. graphics and compute on separate queues).

See VkSharingMode in the Vulkan specification.

pub fn tiling(self, value: ImageTiling) -> Self

Specifies the tiling arrangement of the texel blocks in memory.

The default value is vk::ImageTiling::OPTIMAL.

pub fn image_type(self, value: ImageType) -> Self

The basic dimensionality of the image.

Layers in array textures do not count as a dimension for the purposes of the image type.

pub fn usage(self, value: ImageUsageFlags) -> Self

A bitmask describing the intended usage of the image.

See VkImageUsageFlagBits.

pub fn width(self, value: u32) -> Self

Image extent of the X axis.

Source

impl ImageInfoBuilder

pub fn build(self) -> ImageInfo

Builds a new ImageInfo.

pub fn into_image_view(self) -> ImageViewInfoBuilder

Provides an ImageViewInfo for this format, type, aspect, array elements, and mip levels.