pub struct ImageSubresourceSyncInfo {
pub access_mask: AccessFlags,
pub layout: Option<ImageLayout>,
pub queue_family_index: Option<u32>,
pub range: ImageSubresourceRange,
pub stage_mask: PipelineStageFlags,
}Expand description
Synchronization information for one accessed image subresource range.
Fields
access_mask: AccessFlagsAccess types performed by stage_mask.
layout: Option<ImageLayout>Required image layout for the next external use, when one is defined.
queue_family_index: Option<u32>Queue-family ownership for this subresource, when exclusive ownership is known.
range: ImageSubresourceRangeThe tracked image subresource range.
stage_mask: PipelineStageFlagsPipeline stages that access this range.