pub struct ImageViewInfo {
pub array_layer_count: u32,
pub aspect_mask: ImageAspectFlags,
pub base_array_layer: u32,
pub base_mip_level: u32,
pub format: Format,
pub mip_level_count: u32,
pub view_type: ImageViewType,
}Expand description
Information used to reinterpret an existing Image instance.
Fields
array_layer_count: u32The number of layers that will be contained in the view.
The default value is vk::REMAINING_ARRAY_LAYERS.
aspect_mask: ImageAspectFlagsThe portion of the image that will be contained in the view.
base_array_layer: u32The first array layer that will be contained in the view.
base_mip_level: u32The first mip level that will be contained in the view.
format: FormatThe format and type of the texel blocks that will be contained in the view.
mip_level_count: u32The number of mip levels that will be contained in the view.
The default value is vk::REMAINING_MIP_LEVELS.
view_type: ImageViewTypeThe basic dimensionality of the view.
Implementations
Sourceimpl ImageViewInfo
impl ImageViewInfo
Sourcepub const fn new(format: Format, view_type: ImageViewType) -> ImageViewInfo
pub const fn new(format: Format, view_type: ImageViewType) -> ImageViewInfo
Specifies a default view with the given format and view_type values.
Note
Automatically sets aspect_mask to a suggested value.
Sourcepub fn into_builder(self) -> ImageViewInfoBuilder
pub fn into_builder(self) -> ImageViewInfoBuilder
Converts an ImageViewInfo into an ImageViewInfoBuilder.
Sourceimpl ImageViewInfo
impl ImageViewInfo
Sourcepub fn from_image_info(info: ImageInfo) -> Result<Self, DriverError>
pub fn from_image_info(info: ImageInfo) -> Result<Self, DriverError>
Creates an image view description from image creation info.