pub struct InstanceInfo {
pub api_version: ApiVersion,
pub debug: bool,
pub extension_names: &'static [&'static CStr],
}Expand description
Information used to create an Instance instance.
Fields
api_version: ApiVersionThe Vulkan API version to target.
Defaults to Instance::DEFAULT_API_VERSION.
debug: boolEnables Vulkan validation layers.
This requires a Vulkan SDK installation and will panic when validation errors happen. Additionally, the device must support VK_EXT_private_data.
When stderr is attached to an interactive terminal, validation errors will park the
callback thread for debugger attach.
Set VK_GRAPH_SKIP_VALIDATION_PARK=1 to keep logging validation errors without parking.
NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will report an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.
Platform-specific
macOS: Has no effect unless the loaded feature is enabled.
extension_names: &'static [&'static CStr]Required Vulkan instance extension names to load.
Implementations
Sourceimpl InstanceInfo
impl InstanceInfo
Sourcepub fn builder() -> InstanceInfoBuilder
pub fn builder() -> InstanceInfoBuilder
Creates a default InstanceInfoBuilder.
Sourcepub fn into_builder(self) -> InstanceInfoBuilder
pub fn into_builder(self) -> InstanceInfoBuilder
Converts a InstanceInfo into a InstanceInfoBuilder.