pub struct ParseApiVersionError {
pub major: u32,
pub minor: u32,
pub patch: u32,
pub variant: u32,
}Expand description
Data returned when attempting to parse a Vulkan API version number.
Fields
major: u32The major version indicates a significant change in the API, which will encompass a wholly new version of the specification.
minor: u32The minor version indicates the incorporation of new functionality into the core specification.
patch: u32The patch version indicates bug fixes, clarifications, and language improvements have been incorporated into the specification.
variant: u32The variant indicates the variant of the Vulkan API supported by the implementation. This is always 0 for the Vulkan API.