pub struct AccelerationStructureFeatures {
pub acceleration_structure: bool,
pub acceleration_structure_capture_replay: bool,
pub acceleration_structure_indirect_build: bool,
pub acceleration_structure_host_commands: bool,
pub descriptor_binding_acceleration_structure_update_after_bind: bool,
}Expand description
Features of the physical device for acceleration structures.
Fields
acceleration_structure: boolIndicates whether the implementation supports acceleration structure functionality.
acceleration_structure_capture_replay: boolIndicates whether acceleration structure capture and replay is supported.
acceleration_structure_indirect_build: boolIndicates whether indirect acceleration structure build commands are supported.
acceleration_structure_host_commands: boolIndicates whether acceleration structures can be built on the host.
descriptor_binding_acceleration_structure_update_after_bind: boolIndicates whether acceleration structure descriptors can be updated after bind.