AccelerationStructureProperties

Struct AccelerationStructureProperties 

pub struct AccelerationStructureProperties {
    pub max_geometry_count: u64,
    pub max_instance_count: u64,
    pub max_primitive_count: u64,
    pub max_per_stage_descriptor_accel_structs: u32,
    pub max_descriptor_set_accel_structs: u32,
    pub min_accel_struct_scratch_offset_alignment: u32,
}
Properties of the physical device for acceleration structures.

See VkPhysicalDeviceAccelerationStructurePropertiesKHR.

Fields

max_geometry_count: u64

The maximum number of geometries in a bottom level acceleration structure.

max_instance_count: u64

The maximum number of instances in a top level acceleration structure.

max_primitive_count: u64

The maximum number of triangles or AABBs in all geometries in a bottom level acceleration structure.

max_per_stage_descriptor_accel_structs: u32

The maximum number of acceleration structure bindings that can be accessible to a single shader stage in a pipeline layout.

Descriptor bindings with a descriptor type of VK_DESCRIPTOR_TYPE_ACCELERATION_STRUCTURE_KHR count against this limit.

max_descriptor_set_accel_structs: u32

The maximum number of acceleration structure descriptors that can be included in descriptor bindings in a pipeline layout across all pipeline shader stages and descriptor set numbers.

Descriptor bindings with a descriptor type of VK_DESCRIPTOR_TYPE_ACCELERATION_STRUCTURE_KHR count against this limit.

min_accel_struct_scratch_offset_alignment: u32

The minimum required alignment, in bytes, for scratch data passed in to an acceleration structure build command.