pub struct RayTracingShaderGroup {
pub any_hit_shader: Option<u32>,
pub closest_hit_shader: Option<u32>,
pub general_shader: Option<u32>,
pub intersection_shader: Option<u32>,
pub shader_group_type: RayTracingShaderGroupType,
}Expand description
Describes the set of shader stages to be included in each shader group in the ray tracing pipeline.
Fields
any_hit_shader: Option<u32>The optional index of the any-hit shader in the group if the shader group has type of RayTracingShaderGroupType::TrianglesHitGroup or RayTracingShaderGroupType::ProceduralHitGroup.
closest_hit_shader: Option<u32>The optional index of the closest hit shader in the group if the shader group has type of RayTracingShaderGroupType::TrianglesHitGroup or RayTracingShaderGroupType::ProceduralHitGroup.
general_shader: Option<u32>The index of the ray generation, miss, or callable shader in the group if the shader group has type of RayTracingShaderGroupType::General.
intersection_shader: Option<u32>The index of the intersection shader in the group if the shader group has type of RayTracingShaderGroupType::ProceduralHitGroup.
shader_group_type: RayTracingShaderGroupTypeThe type of hit group specified in this structure.
Implementations
Sourceimpl RayTracingShaderGroup
impl RayTracingShaderGroup
Sourcepub fn new_general(general_shader: impl Into<Option<u32>>) -> Self
pub fn new_general(general_shader: impl Into<Option<u32>>) -> Self
Creates a new general-type shader group with the given general shader.