pub struct SamplerInfoBuilder { /* private fields */ }Expand description
Builder for SamplerInfo.
Implementations
Sourceimpl SamplerInfoBuilder
impl SamplerInfoBuilder
Sourcepub fn flags(self, value: SamplerCreateFlags) -> Self
pub fn flags(self, value: SamplerCreateFlags) -> Self
Bitmask specifying additional parameters of a sampler.
Sourcepub fn mag_filter(self, value: Filter) -> Self
pub fn mag_filter(self, value: Filter) -> Self
Specifies the magnification filter to apply to texture lookups.
The default value is vk::Filter::NEAREST.
Sourcepub fn min_filter(self, value: Filter) -> Self
pub fn min_filter(self, value: Filter) -> Self
Specifies the minification filter to apply to texture lookups.
The default value is vk::Filter::NEAREST.
Sourcepub fn mipmap_mode(self, value: SamplerMipmapMode) -> Self
pub fn mipmap_mode(self, value: SamplerMipmapMode) -> Self
A value specifying the mipmap filter to apply to lookups.
The default value is vk::SamplerMipmapMode::NEAREST.
Sourcepub fn address_mode_u(self, value: SamplerAddressMode) -> Self
pub fn address_mode_u(self, value: SamplerAddressMode) -> Self
A value specifying the addressing mode for U coordinates outside [0, 1).
The default value is vk::SamplerAddressMode::REPEAT.
Sourcepub fn address_mode_v(self, value: SamplerAddressMode) -> Self
pub fn address_mode_v(self, value: SamplerAddressMode) -> Self
A value specifying the addressing mode for V coordinates outside [0, 1).
The default value is vk::SamplerAddressMode::REPEAT.
Sourcepub fn address_mode_w(self, value: SamplerAddressMode) -> Self
pub fn address_mode_w(self, value: SamplerAddressMode) -> Self
A value specifying the addressing mode for W coordinates outside [0, 1).
The default value is vk::SamplerAddressMode::REPEAT.
Sourcepub fn mip_lod_bias<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
pub fn mip_lod_bias<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
Bias added to the mipmap LOD calculation and to bias provided by SPIR-V image sampling instructions.
Sourcepub fn anisotropy_enable(self, value: bool) -> Self
pub fn anisotropy_enable(self, value: bool) -> Self
Enables anisotropic filtering.
Sourcepub fn max_anisotropy<VALUE: Into<OrderedFloat<f32>>>(
self,
value: VALUE,
) -> Self
pub fn max_anisotropy<VALUE: Into<OrderedFloat<f32>>>( self, value: VALUE, ) -> Self
The anisotropy value clamp used by the sampler when anisotropy_enable is true.
If anisotropy_enable is false, max_anisotropy is ignored.
Sourcepub fn compare_enable(self, value: bool) -> Self
pub fn compare_enable(self, value: bool) -> Self
Enables comparison against a reference value during lookups.
Sourcepub fn compare_op(self, value: CompareOp) -> Self
pub fn compare_op(self, value: CompareOp) -> Self
Specifies the comparison operator to apply to fetched data before filtering.
Sourcepub fn min_lod<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
pub fn min_lod<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
Minimum LOD value used to clamp the computed level of detail.
Sourcepub fn max_lod<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
pub fn max_lod<VALUE: Into<OrderedFloat<f32>>>(self, value: VALUE) -> Self
Maximum LOD value used to clamp the computed level of detail.
To avoid clamping the maximum value, set max_lod to vk::LOD_CLAMP_NONE.
Sourcepub fn border_color(self, value: BorderColor) -> Self
pub fn border_color(self, value: BorderColor) -> Self
Specifies the predefined border color to use.
The default value is vk::BorderColor::FLOAT_TRANSPARENT_BLACK.
Sourcepub fn unnormalized_coordinates(self, value: bool) -> Self
pub fn unnormalized_coordinates(self, value: bool) -> Self
Controls whether to use unnormalized or normalized texel coordinates to address texels of the image.
When set to true, the range of the image coordinates used to lookup the texel is in the
range of zero to the image size in each dimension.
When set to false the range of image coordinates is zero to one.
See VkSamplerCreateInfo.
Sourcepub fn reduction_mode(self, value: SamplerReductionMode) -> Self
pub fn reduction_mode(self, value: SamplerReductionMode) -> Self
Specifies sampler reduction mode.
Setting magnification filter (mag_filter) to vk::Filter::NEAREST
disables sampler reduction mode.
The default value is vk::SamplerReductionMode::WEIGHTED_AVERAGE.
Sourceimpl SamplerInfoBuilder
impl SamplerInfoBuilder
Sourcepub fn build(self) -> SamplerInfo
pub fn build(self) -> SamplerInfo
Builds a new SamplerInfo.