pub struct SpecializationMap {
pub data: Vec<u8>,
pub entries: Vec<SpecializationMapEntry>,
}Expand description
Describes specialized constant values.
Fields
data: Vec<u8>A buffer of data which holds the constant values.
entries: Vec<SpecializationMapEntry>Mapping of locations within the constant value data which describe each individual constant.
Implementations
Sourceimpl SpecializationMap
impl SpecializationMap
Sourcepub fn constant(self, constant_id: u32, offset: u32, size: usize) -> Self
pub fn constant(self, constant_id: u32, offset: u32, size: usize) -> Self
Adds a single constant offset and size to the map and returns the map for further building.
Sourcepub fn set_constant(&mut self, constant_id: u32, offset: u32, size: usize)
pub fn set_constant(&mut self, constant_id: u32, offset: u32, size: usize)
Adds a single constant offset and size to the map and returns the map for further building.