Surface

Struct Surface 

pub struct Surface {
    pub device: Device,
    pub handle: SurfaceKHR,
}
Smart pointer handle to a vk::SurfaceKHR object.

Fields

device: Device

The device which owns this surface resource.

Note: This field is read-only.

handle: SurfaceKHR

The native Vulkan resource handle of this surface.

Note: This field is read-only.

Implementations

Source

impl Surface

pub fn capabilities(&self) -> Result<SurfaceCapabilitiesKHR, DriverError>

Query surface capabilities

pub fn create( device: &Device, display: impl HasDisplayHandle, window: impl HasWindowHandle, ) -> Result<Self, DriverError>

Create a surface from a raw window display handle.

device must have been created with platform specific surface extensions enabled.

pub fn formats(&self) -> Result<Vec<SurfaceFormatKHR>, DriverError>

Lists the supported surface formats.

pub fn linear(formats: &[SurfaceFormatKHR]) -> Option<SurfaceFormatKHR>

Helper function to automatically select the best UNORM format, if one is available.

pub fn linear_or_default(formats: &[SurfaceFormatKHR]) -> SurfaceFormatKHR

Helper function to automatically select the best UNORM format.

NOTE: The default surface format is undefined, and although legal the results may not support presentation. You should prefer to use Surface::linear and fall back to supported values manually.

pub fn physical_device_support( &self, queue_family_index: u32, ) -> Result<bool, DriverError>

Returns true if the given queue family supports presentation on this surface.

pub fn present_modes(&self) -> Result<Vec<PresentModeKHR>, DriverError>

Query supported presentation modes.

pub fn srgb(formats: &[SurfaceFormatKHR]) -> Option<SurfaceFormatKHR>

Helper function to automatically select the best sRGB format, if one is available.

pub fn srgb_or_default(formats: &[SurfaceFormatKHR]) -> SurfaceFormatKHR

Helper function to automatically select the best sRGB format.

NOTE: The default surface format is undefined, and although legal the results may not support presentation. You should prefer to use Surface::srgb and fall back to supported values manually.