PresentResult

Enum PresentResult 

pub enum PresentResult {
    QueuedOptimal,
    QueuedSuboptimal,
    NotQueued(PresentError),
}
Result of one image in a queue presentation batch.

Variants



QueuedOptimal

The image was queued and the swapchain remained optimal.



QueuedSuboptimal

The image was queued, but the swapchain should be recreated soon.



NotQueued(PresentError)

The image was not queued for presentation.

Implementations

Source

impl PresentResult

pub fn queued(self) -> bool

Returns true if this image was queued for presentation.

pub fn suboptimal(self) -> bool

Returns true if this present reported suboptimal state.