SwapchainError

Enum SwapchainError 

pub enum SwapchainError {
    DeviceLost,
    Driver(DriverError),
    FullScreenExclusiveModeLost,
    NotReady,
    SurfaceLost,
    Timeout,
}
Describes the condition of a swapchain.

Variants



DeviceLost

This frame is lost but more may be acquired later.



Driver(DriverError)

Recoverable driver error.



FullScreenExclusiveModeLost

Exclusive full-screen ownership was lost and the swapchain should be recreated.



NotReady

No image is currently available, but a future acquire may succeed.



SurfaceLost

The surface was lost and must be recreated, which includes any operating system window.



Timeout

No image was acquired before the configured acquire timeout elapsed.