pub struct PresentBatchError {
pub results: Box<[Option<PresentResult>]>,
pub source: PresentFailure,
}Expand description
Error returned by a presentation batch.
Fields
results: Box<[Option<PresentResult>]>Per-input results in the same order as the submitted PresentInfo values.
Entries are None when presentation did not run far enough to determine that input’s
result.
source: PresentFailureThe batch-level failure.