pub enum AnyAccelerationStructureNode {
Arg(AccelerationStructureArg),
Owned(AccelerationStructureNode),
Pooled(AccelerationStructureLeaseNode),
}Expand description
Specifies either an owned acceleration structure or one obtained from a pool.
Variants
Arg(AccelerationStructureArg)
An acceleration structure supplied as a command stream argument.
Owned(AccelerationStructureNode)
An owned acceleration structure.
Pooled(AccelerationStructureLeaseNode)
An acceleration structure obtained from a pool.