pub enum AnyImageNode {
Image(ImageNode),
ImageLease(ImageLeaseNode),
SwapchainImage(SwapchainImageNode),
}Expand description
Specifies either an owned image or one obtained from a pool.
The image may also be a special swapchain type of image.
Variants
Image(ImageNode)
An owned image.
ImageLease(ImageLeaseNode)
An image obtained from a pool.
SwapchainImage(SwapchainImageNode)
A special swapchain image.