pub struct AccelerationStructureNode { /* private fields */ }Expand description
A graph-local handle for a bound resource.
Node handles are only valid with the graph that produced them.
When the checked feature is enabled, using a node with a different graph will
panic immediately.
When checked is disabled, this ownership check is skipped for zero-overhead
builds, so cross-graph node misuse is invalid and may resolve to the wrong resource.