Lease

Struct Lease 

pub struct Lease<T> { /* private fields */ }
Holds a pooled resource and implements Drop in order to return the resource.

This simple wrapper type implements only the AsRef, AsMut, Deref and DerefMut traits and provides no other functionality. A freshly obtained resource is guaranteed to have no other owners and may be mutably accessed.

Implementations

Source

impl Lease<AccelerationStructure>

pub fn debug_name(self, name: impl Into<String>) -> Self

Sets the debugging name assigned to this acceleration structure.

Source

impl Lease<Buffer>

pub fn debug_name(self, name: impl Into<String>) -> Self

Sets the debugging name assigned to this buffer.

Source

impl Lease<Image>

pub fn debug_name(self, name: impl Into<String>) -> Self

Sets the debugging name assigned to this image.