PoolConfig

Struct PoolConfig 

pub struct PoolConfig {
    pub accel_struct_capacity: usize,
    pub buffer_capacity: usize,
    pub image_capacity: usize,
}
Information used to create a FifoPool, HashPool or LazyPool instance.

Fields

accel_struct_capacity: usize

The maximum size of a single bucket of acceleration structure resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored acceleration structure instances.

buffer_capacity: usize

The maximum size of a single bucket of buffer resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored buffer instances.

image_capacity: usize

The maximum size of a single bucket of image resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored image instances.

Implementations

Source

impl PoolConfig

pub const DEFAULT_RESOURCE_CAPACITY: usize = 16

The maximum size of a single bucket of resource instances.

pub fn builder() -> PoolConfigBuilder

Creates a default PoolConfigBuilder.

pub fn into_builder(self) -> PoolConfigBuilder

Converts a PoolConfig into a PoolConfigBuilder.

pub const fn with_capacity(resource_capacity: usize) -> Self

Constructs a new PoolConfig with the given acceleration structure, buffer and image resource capacity for any single bucket.