PoolConfigBuilder

Struct PoolConfigBuilder 

pub struct PoolConfigBuilder { /* private fields */ }
Builder for PoolConfig.

Implementations

Source

impl PoolConfigBuilder

pub fn accel_struct_capacity(self, value: usize) -> Self

The maximum size of a single bucket of acceleration structure resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored acceleration structure instances.

pub fn buffer_capacity(self, value: usize) -> Self

The maximum size of a single bucket of buffer resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored buffer instances.

pub fn image_capacity(self, value: usize) -> Self

The maximum size of a single bucket of image resource instances. The default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.

Note

Individual Pool implementations store varying numbers of buckets. Read the documentation of each implementation to understand how this affects total number of stored image instances.

Source

impl PoolConfigBuilder

pub fn build(self) -> PoolConfig

Builds a new PoolConfig.