StreamCommand

Struct StreamCommand 

pub struct StreamCommand<'a> { /* private fields */ }
A command being recorded into a CommandStreamMut.

let stream = CommandStream::finalize(|stream| {
    stream
        .begin_cmd()
        .debug_name("stream command")
        .record_cmd(|cmd| {
            let _ = cmd;
        });
})
.into_stream();

Implementations

Source

impl<'a> StreamCommand<'a>

pub fn bind_resource<R>(&mut self, resource: R) -> R::Node
where R: Resource,

Stream equivalent of Command::bind_resource.

pub fn bind_pipeline<P>(self, pipeline: P) -> P::Command
where P: StreamPipeline<'a>,

Stream equivalent of Command::bind_pipeline.

pub fn debug_name(self, name: impl Into<String>) -> Self

Stream equivalent of Command::debug_name.

pub fn record_cmd( self, func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static, ) -> Self

Stream equivalent of Command::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

pub fn record_cmd_mut( &mut self, func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static, )

Mutable-borrow stream equivalent of Command::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

pub fn resource_access<N>(self, resource_node: N, access: AccessType) -> Self
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Stream equivalent of Command::resource_access.

pub fn set_resource_access<N>(&mut self, resource_node: N, access: AccessType)
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Mutable-borrow stream equivalent of Command::resource_access.