StreamPipelineCommand

Struct StreamPipelineCommand 

pub struct StreamPipelineCommand<'a, T> { /* private fields */ }
A stream command with a bound pipeline.

let stream = CommandStream::finalize(|stream| {
    stream
        .begin_cmd()
        .bind_pipeline(&pipeline)
        .record_cmd(|cmd| {
            cmd.dispatch(1, 1, 1);
        });
})
.into_stream();

Implementations

Source

impl<'a, T> StreamPipelineCommand<'a, T>

pub fn bind_resource<R>(&mut self, resource: R) -> R::Node
where R: Resource,

Stream equivalent of PipelineCommand::bind_resource.

pub fn resource_access<N>(self, resource_node: N, access: AccessType) -> Self
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Stream equivalent of PipelineCommand::resource_access.

pub fn set_resource_access<N>( &mut self, resource_node: N, access: AccessType, ) -> &mut Self
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Mutable-borrow stream equivalent of PipelineCommand::resource_access.

Source

impl StreamPipelineCommand<'_, ComputePipeline>

pub fn record_cmd( self, func: impl for<'r> Fn(ComputeCommandRef<'r>) + Send + Sync + 'static, ) -> Self

Stream equivalent of PipelineCommand::<ComputePipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

pub fn record_cmd_mut( &mut self, func: impl for<'r> Fn(ComputeCommandRef<'r>) + Send + Sync + 'static, )

Mutable-borrow stream equivalent of PipelineCommand::<ComputePipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

Source

impl StreamPipelineCommand<'_, GraphicsPipeline>

pub fn depth_stencil(self, depth_stencil: impl Into<DepthStencilInfo>) -> Self

pub fn color_attachment_image( self, color_attachment: u32, image: impl Into<AnyImageNode>, load: LoadOp<ClearColorValue>, store: StoreOp, ) -> Self

pub fn color_attachment_image_view( self, color_attachment: u32, image: impl Into<AnyImageNode>, image_view_info: impl Into<ImageViewInfo>, load: LoadOp<ClearColorValue>, store: StoreOp, ) -> Self

pub fn depth_stencil_attachment_image( self, image: impl Into<AnyImageNode>, load: LoadOp<ClearDepthStencilValue>, store: StoreOp, ) -> Self

pub fn record_cmd( self, func: impl for<'r> Fn(GraphicsCommandRef<'r>) + Send + Sync + 'static, ) -> Self

Stream equivalent of PipelineCommand::<GraphicsPipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

pub fn record_cmd_mut( &mut self, func: impl for<'r> Fn(GraphicsCommandRef<'r>) + Send + Sync + 'static, )

Mutable-borrow stream equivalent of PipelineCommand::<GraphicsPipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

Source

impl StreamPipelineCommand<'_, RayTracingPipeline>

pub fn record_cmd( self, func: impl for<'r> Fn(RayTracingCommandRef<'r>) + Send + Sync + 'static, ) -> Self

Stream equivalent of PipelineCommand::<RayTracingPipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.

pub fn record_cmd_mut( &mut self, func: impl for<'r> Fn(RayTracingCommandRef<'r>) + Send + Sync + 'static, )

Mutable-borrow stream equivalent of PipelineCommand::<RayTracingPipeline>::record_cmd.

Unlike graph commands, stream callbacks must be reusable and therefore implement Fn + Send + Sync + 'static.