pub type ImageArg = StreamArg<Image>;Expand description
A stream argument for an image.
let stream = CommandStream::finalize(|stream| -> ImageArg {
stream.arg(ImageInfo::image_2d(
128,
128,
vk::Format::R8G8B8A8_UNORM,
vk::ImageUsageFlags::SAMPLED,
))
})
.into_stream();Aliased Type
pub struct ImageArg { /* private fields */ }Trait Implementations
Sourceimpl Subresource for ImageArg
impl Subresource for ImageArg
Sourcetype Info = ImageViewInfo
type Info = ImageViewInfo
The information about the subresource when bound directly to shader descriptors.
Sourcetype Range = ImageSubresourceRange
type Range = ImageSubresourceRange
The information about the subresource when used indirectly by any part of a graph.