pub struct GraphBuilder { /* private fields */ }Expand description
Builder for incrementally constructing a Graph.
Implementations
Sourceimpl GraphBuilder
impl GraphBuilder
Sourcepub fn bind_resource<R>(&mut self, resource: R) -> R::Nodewhere
R: Resource,
pub fn bind_resource<R>(&mut self, resource: R) -> R::Nodewhere
R: Resource,
Binds a Vulkan buffer, image, or acceleration structure resource to this graph.
Sourcepub fn blit_image(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyImageNode>,
filter: Filter,
) -> Self
pub fn blit_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, filter: Filter, ) -> Self
Copies an image, potentially performing format conversion.
Sourcepub fn clear_color_image(
self,
image: impl Into<AnyImageNode>,
color: impl Into<ClearColorValue>,
) -> Self
pub fn clear_color_image( self, image: impl Into<AnyImageNode>, color: impl Into<ClearColorValue>, ) -> Self
Clears a color image.
Sourcepub fn clear_depth_stencil_image(
self,
image: impl Into<AnyImageNode>,
depth: f32,
stencil: u32,
) -> Self
pub fn clear_depth_stencil_image( self, image: impl Into<AnyImageNode>, depth: f32, stencil: u32, ) -> Self
Clears a depth/stencil image.
Sourcepub fn copy_buffer(
self,
src: impl Into<AnyBufferNode>,
dst: impl Into<AnyBufferNode>,
) -> Self
pub fn copy_buffer( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyBufferNode>, ) -> Self
Copies data between buffers.
Sourcepub fn copy_buffer_to_image(
self,
src: impl Into<AnyBufferNode>,
dst: impl Into<AnyImageNode>,
) -> Self
pub fn copy_buffer_to_image( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyImageNode>, ) -> Self
Copies data from a buffer into an image.
Sourcepub fn copy_image(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyImageNode>,
) -> Self
pub fn copy_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, ) -> Self
Copies all layers of a source image to a destination image.
Sourcepub fn copy_image_to_buffer(
self,
src: impl Into<AnyImageNode>,
dst: impl Into<AnyBufferNode>,
) -> Self
pub fn copy_image_to_buffer( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyBufferNode>, ) -> Self
Copies image data into a buffer.
Sourcepub fn fill_buffer(
self,
buffer: impl Into<AnyBufferNode>,
region: Range<DeviceSize>,
data: u32,
) -> Self
pub fn fill_buffer( self, buffer: impl Into<AnyBufferNode>, region: Range<DeviceSize>, data: u32, ) -> Self
Fills a region of a buffer with a fixed value.
Sourcepub fn update_buffer(
self,
buffer: impl Into<AnyBufferNode>,
offset: DeviceSize,
data: impl AsRef<[u8]> + 'static + Send,
) -> Self
pub fn update_buffer( self, buffer: impl Into<AnyBufferNode>, offset: DeviceSize, data: impl AsRef<[u8]> + 'static + Send, ) -> Self
Records a vkCmdUpdateBuffer command.