RecordSelection

Enum RecordSelection 

pub enum RecordSelection<'a> {
    All,
    Dependencies(AnyNode),
    Node(AnyNode),
    Nodes(&'a [AnyNode]),
}
Selects which pending work from a Submission should be recorded.

Variants



All

Record all remaining work.



Dependencies(AnyNode)

Record prerequisite work, excluding commands that directly access the target node.



Node(AnyNode)

Record work required by the target node.



Nodes(&'a [AnyNode])

Record work required by all of the target nodes.

Nodes are processed sequentially in slice order against the same evolving submission state.

Implementations

Source

impl<'a> RecordSelection<'a>

pub fn dependencies(node: impl Into<AnyNode>) -> Self

Creates a selection that records prerequisite work for node without recording commands that directly access it.

pub fn node(node: impl Into<AnyNode>) -> Self

Creates a selection that records work required by node.

pub fn nodes(nodes: &'a [AnyNode]) -> Self

Creates a selection that records work required by all nodes.

Nodes are processed in slice order.