Node

Trait Node 

pub trait Node: NodeSealed {
    type Resource;
    type SyncInfo;
}
A Vulkan resource which has been bound to a Graph.

See Graph::bind_resource.

This trait is sealed and cannot be implemented outside of vk-graph.

Required Associated Types

type Resource

The Vulkan buffer, image, or acceleration structure type.

type SyncInfo

Synchronization state snapshot returned for this node’s resource type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Node for AccelerationStructureLeaseNode

Source

impl Node for AccelerationStructureNode

Source

impl Node for AnyAccelerationStructureNode

Source

impl Node for AnyBufferNode

Source

impl Node for AnyImageNode

Source

impl Node for BufferLeaseNode

Source

impl Node for BufferNode

Source

impl Node for ImageLeaseNode

Source

impl Node for ImageNode

Source

impl Node for StreamArg<AccelerationStructure>

Source

impl Node for StreamArg<Buffer>

Source

impl Node for StreamArg<Image>

Source

impl Node for SwapchainImageNode