pub trait Resource: ResourceSealed {
type Node;
}Expand description
A Vulkan resource which may be bound to a Graph.
See Graph::bind_resource and
Command::bind_resource.
This trait is sealed and cannot be implemented outside of vk-graph.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".