Crate vk_graph

Crate vk_graph 

A high-performance Vulkan driver with automated resource management and execution. Start with Graph — bind resources, record commands, and submit for execution.

  • Beginner: Graph, cmd, node, pool — the high-level graph API
  • Intermediate: driver — smart-pointer Vulkan wrappers (resources, pipelines, device)
  • Expert: driver re-exports ash and vk_sync — raw Vulkan bindings

For installation, guides, and examples see the Guide Book.

Modules

cmd
Strongly-typed Graph commands.
driver
ADVANCED: Raw Vulkan wrappers. Most users should use Graph, cmd, and node instead.
node
Handles for Vulkan smart-pointer resources.
pool
Resource pooling, requesting, and caching types.
stream
Reusable command streams.
submission
Submission and recording types.

Macros

lazy_str
Creates a LazyStr from format_args! without eagerly allocating a String.

Structs

CommandExecution
Tracks whether a graph command has completed device execution.
CommandExecutionAbandoned
Error returned when a tracked command execution can no longer complete.
Graph
A composable graph of Vulkan command buffer operations.
GraphBuilder
Builder for incrementally constructing a Graph.
LazyStr
Lazily formats string arguments on first string access.

Enums

LoadOp
Specifies the state of a color or combined depth and stencil attachment image during graphics render pass framebuffer load operations.
StoreOp
Specifies the state of a color or combined depth and stencil attachment image after graphics render pass framebuffer store operations.

Traits

Node
A Vulkan resource which has been bound to a Graph.
Resource
A Vulkan resource which may be bound to a Graph.