Crate vk_graph

Crate vk_graph 

This crate provides a high-performance Vulkan driver featuring automated resource management and execution.

For an overview, including installation and typical usage, see the Guide Book.

Modules

cmd
Strongly-typed Graph commands.
driver
Vulkan interface based on smart pointers.
node
Handles for Vulkan smart-pointer resources.
pool
Resource pooling, requesting, and caching types.

Structs

Graph
A composable graph of Vulkan command buffer operations.
Submission
A structure which can optimize and submit Graph instances.

Traits

Node
A Vulkan resource which has been bound to a Graph.
Resource
A Vulkan resource which may be bound to a Graph.