This crate provides a high-performance Vulkan driver featuring automated resource management and execution.
For an overview, including installation and typical usage, see the Guide Book.
Modules
- cmd
- Strongly-typed
Graphcommands. - driver
- Vulkan interface based on smart pointers.
- node
- Handles for Vulkan smart-pointer resources.
- pool
- Resource pooling, requesting, and caching types.
Structs
- Graph
- A composable graph of Vulkan command buffer operations.
- Submission
- A structure which can optimize and submit
Graphinstances.