Strongly-typed Graph commands.
Structs
- Binding
- Describes the SPIR-V binding index, and optionally a specific descriptor set and array index.
- Build
Acceleration Structure Indirect Info - Specifies the information and data used to build an acceleration structure with some parameters sourced on the device.
- Build
Acceleration Structure Info - Specifies the information and data used to build an acceleration structure.
- Command
- A general-purpose Vulkan command which may contain acceleration structure operations, transfers, or shader pipelines.
- Command
Ref - Recording interface for general Vulkan commands.
- Compute
Command Ref - Recording interface for computing commands.
- Graphic
Command Ref - Recording interface for drawing commands.
- Pipeline
Command - A
Commandwhich has been bound to a particular compute, graphic, or ray-trace pipeline. - RayTrace
Command Ref - Recording interface for ray tracing commands.
- Update
Acceleration Structure Indirect Info - Specifies the information and data used to update an acceleration structure with some parameters sourced on the device.
- Update
Acceleration Structure Info - Specifies the information and data used to update an acceleration structure.
Enums
- Clear
Color Value - Structure specifying a clear color value.
- LoadOp
- Specifies the state of a color or combined depth and stencil attachment image during graphic render pass framebuffer load operations.
- StoreOp
- Specifies the state of a color or combined depth and stencil attachment image after graphic render pass framebuffer store operations.
Traits
- Pipeline
- A trait for pipelines which may be bound to a
Command. - Subresource
- Allows for a resource to be reinterpreted as differently formatted data.