Strongly-typed Graph commands.
Lifecycle
Commands follow a builder-style chain:
Graph::begin_cmdopens aCommand.- Declare resource accesses with
Command::resource_accessor bind a shader pipeline withCommand::bind_pipeline, returning aPipelineCommand. - With a pipeline, declare shader bindings with
PipelineCommand::shader_resource_access. - Record work with
record_cmd— available on bothCommandandPipelineCommand. - The command auto-closes when dropped or when
Graph::finalizeis called.
A single command can call record_cmd multiple times — each call creates a separate
“execution” within that command. Executions within a command stay in the specified
order, but the graph system may re-order entire commands or merge them during
submission for optimal scheduling.
Re-exports
Structs
- Binding
- Describes the SPIR-V binding index, and optionally a specific descriptor set and array index.
- Build
Acceleration Structure Indirect Info - Specifies the information and data used to build an acceleration structure with some parameters sourced on the device.
- Build
Acceleration Structure Info - Specifies the information and data used to build an acceleration structure.
- Command
- A general-purpose Vulkan command which may contain acceleration structure operations, transfers, or shader pipelines.
- Command
Ref - Recording interface for general Vulkan commands.
- Compute
Command Ref - Recording interface for compute commands.
- Graphics
Command Ref - Recording interface for drawing commands.
- Pipeline
Command - A
Commandwhich has been bound to a particular compute, graphics, or ray tracing pipeline. - RayTracing
Command Ref - Recording interface for ray tracing commands.
- Update
Acceleration Structure Indirect Info - Specifies the information and data used to update an acceleration structure with some parameters sourced on the device.
- Update
Acceleration Structure Info - Specifies the information and data used to update an acceleration structure.
Enums
- Clear
Color Value - Structure specifying a clear color value.
Traits
- Pipeline
- A trait for pipelines which may be bound to a
Command. - Subresource
- Allows for a resource to be reinterpreted as differently formatted data.