Command

Struct Command 

pub struct Command<'a> { /* private fields */ }
A general-purpose Vulkan command which may contain acceleration structure operations, transfers, or shader pipelines.

There are four main uses of a Command:

  1. Bind resources (Self::bind_resource)
  2. Declare resource accesses (Self::resource_access)
  3. Record general-purpose command buffers or acceleration structure operations (Self::record_cmd)
  4. Bind shader pipelines (Self::bind_pipeline)

When bound, a shader pipeline consumes the Command and returns a PipelineCommand which provides command recording functions specific to each pipeline type.

Implementations

Source

impl<'a> Command<'a>

pub fn builder(graph: &'a mut Graph) -> CommandBuilder<'a>

Begins a command builder in graph.

pub fn into_builder(self) -> CommandBuilder<'a>

Converts this command into a builder.

pub fn track_execution(&mut self) -> CommandExecution

Returns a handle that tracks whether this graph command has completed device execution.

This may be called multiple times. Each returned handle independently observes the same command execution.

pub fn write_timestamp(&mut self) -> TimestampQuery

Records a timestamp query point at the current position in this command.

A timestamp written before any command work is recorded at the start of this command. After command work is recorded, timestamps are recorded after the most recently added execution.

See Graph::write_timestamp for graph-boundary timestamps.

pub fn bind_resource<R>(&mut self, resource: R) -> R::Node
where R: Resource,

Binds a Vulkan buffer, image, or acceleration structure resource to the graph associated with this command.

Bound nodes may be used in commands for pipeline and shader operations.

pub fn bind_pipeline<P>(self, pipeline: P) -> P::Command
where P: Pipeline<'a>,

Binds a shader pipeline to the current command, allowing for strongly typed access to the related functions.

pub fn debug_name(self, name: impl Into<String>) -> Self

Sets a debugging name, but only in debug builds.

pub fn end_cmd(self) -> &'a mut Graph

Finalize the recording of this command and return to the Graph where you may record additional commands.

pub fn record_cmd( self, func: impl FnOnce(CommandRef<'_>) + Send + 'static, ) -> Self

Begin recording general-purpose work for this graph command.

This is the entry point for building and updating an AccelerationStructure instance.

The provided closure allows you to run any Vulkan code, or interoperate with other Vulkan code and interfaces.

pub fn record_cmd_mut( &mut self, func: impl FnOnce(CommandRef<'_>) + Send + 'static, )

Mutable-borrow form of Self::record_cmd.

pub fn blit_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, filter: Filter, regions: impl AsRef<[ImageBlit]> + 'static + Send, ) -> Self

Blits image regions.

pub fn clear_color_image( self, image: impl Into<AnyImageNode>, color: impl Into<ClearColorValue>, ) -> Self

Clears a color image.

pub fn clear_depth_stencil_image( self, image: impl Into<AnyImageNode>, depth: f32, stencil: u32, ) -> Self

Clears a depth/stencil image.

pub fn copy_buffer( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyBufferNode>, regions: impl AsRef<[BufferCopy]> + 'static + Send, ) -> Self

Copies data between buffer regions.

pub fn copy_buffer_to_image( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyImageNode>, regions: impl AsRef<[BufferImageCopy]> + 'static + Send, ) -> Self

Copies data from a buffer into image regions.

pub fn copy_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, regions: impl AsRef<[ImageCopy]> + 'static + Send, ) -> Self

Copies data between image regions.

pub fn copy_image_to_buffer( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyBufferNode>, regions: impl AsRef<[BufferImageCopy]> + 'static + Send, ) -> Self

Copies image region data into a buffer.

pub fn fill_buffer( self, buffer: impl Into<AnyBufferNode>, region: Range<DeviceSize>, data: u32, ) -> Self

Fills a region of a buffer with a fixed value.

pub fn resource<N>(&self, resource_node: N) -> &N::Resource
where N: Node,

Returns a borrow of the original Vulkan resource (buffer, image or acceleration structure) which the given bound resource node represents.

pub fn resource_access<N>(self, resource_node: N, access: AccessType) -> Self
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Informs the command that recorded work will read or write resource_node using access.

An access function must be called for resource_node before it is used within a recording function.

pub fn set_debug_name(&mut self, name: impl Into<String>) -> &mut Self

Mutable-borrow form of Self::debug_name.

pub fn set_resource_access<N>(&mut self, resource_node: N, access: AccessType)
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Mutable-borrow form of Self::resource_access.

pub fn set_subresource_access<N>( &mut self, resource_node: N, subresource: impl Into<N::Range>, access: AccessType, )
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Mutable-borrow form of Self::subresource_access.

pub fn subresource_access<N>( self, resource_node: N, subresource: impl Into<N::Range>, access: AccessType, ) -> Self
where N: Node + Subresource, SubresourceRange: From<N::Range>,

Informs the command that recorded work will read or write the subresource of resource_node using access.

An access function must be called for resource_node before it is used within a recording function.

pub fn update_buffer( self, buffer: impl Into<AnyBufferNode>, offset: DeviceSize, data: impl AsRef<[u8]> + 'static + Send, ) -> Self

Records a vkCmdUpdateBuffer command.

Vulkan requires data to be at most 65536 bytes.

These constraints are validated by the Vulkan Validation Layer (VVL) when it is active. When the checked feature is enabled, vk-graph also validates the data size and bounds before recording the command.