Module driver

Module driver 

ADVANCED: Raw Vulkan wrappers. Most users should use Graph, cmd, and node instead.

Resources

Resources are created and destroyed using RAII-style wrapper structures.

The following resources are available:

Resources are logically mutable. All resource types contain useful read-only public fields, for example:

Resources use atomic AccessType values to maintain consistency and track changes.

Pipelines

Pipelines enable reading and writing resources using shader code running on physical graphics hardware.

The following pipelines are available:

Pipelines are immutable. All pipeline types contain useful public methods, for example:

Modules

accel_struct
Acceleration structure resource types
buffer
Buffer resource types
cmd_buf
Command buffer types
compute
Compute pipeline types.
device
Logical device types
fence
Fence types.
graphics
Graphics pipeline types
image
Image resource types
instance
Vulkan initialization types.
physical_device
Physical device types.
ray_tracing
Ray tracing pipeline types
render_pass
Render pass related types.
shader
Shader reflection and pipeline-stage descriptions.
surface
Native platform window surface types.
swapchain
Native window presentation types.

Enums

DriverError
Describes the general category of all graphics driver failure cases.

Functions

format_texel_block_extent
Returns the extent of a block of texels for the given Vulkan format. Uncompressed formats typically have a block extent of (1, 1).
format_texel_block_size
Returns number of bytes used to store one texel block (a single addressable element of an uncompressed image, or a single compressed block of a compressed image).