CommandBuffer

Struct CommandBuffer 

pub struct CommandBuffer {
    pub device: Device,
    pub fence: Fence,
    pub handle: CommandBuffer,
    pub info: CommandBufferInfo,
    /* private fields */
}
Represents a Vulkan command buffer to which some work has been submitted.

Fields

device: Device

The device which owns this command buffer resource.

Note: This field is read-only.

fence: Fence

The native Vulkan fence handle of this command buffer.

Note: This field is read-only.

handle: CommandBuffer

The native Vulkan resource handle of this command buffer.

Note: This field is read-only.

info: CommandBufferInfo

Information used to create this object.

Implementations

Source

impl CommandBuffer

pub fn create( device: &Device, info: CommandBufferInfo, ) -> Result<Self, DriverError>

Creates a command buffer allocation backed by a transient resettable command pool.

pub fn drop_after_executed(&mut self, x: impl Debug + Send + 'static)

Drops an item after execution has been completed.

pub fn has_executed(&self) -> Result<bool, DriverError>

Returns true after the GPU has executed the previous submission to this command buffer.

See Self::wait_until_executed to block while checking.

pub fn wait_until_executed(&mut self) -> Result<(), DriverError>

Stalls by blocking the current thread until the GPU has executed the previous submission to this command buffer.

See Self::has_executed to check without blocking.