pub struct DeviceInfo {
pub debug: bool,
pub physical_device_index: usize,
}Expand description
Information used to create a Device instance.
Fields
debug: boolEnables Vulkan validation layers.
This requires a Vulkan SDK installation and will cause validation errors to introduce panics as they happen.
NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will throw an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.
Platform-specific
macOS: Has no effect unless the loaded feature is enabled.
physical_device_index: usizeIndex of the PhysicalDevice from the available devices. See
Instance::physical_devices.
Implementations
Sourceimpl DeviceInfo
impl DeviceInfo
Sourcepub fn builder() -> DeviceInfoBuilder
pub fn builder() -> DeviceInfoBuilder
Creates a default DeviceInfoBuilder.
Sourcepub fn into_builder(self) -> DeviceInfoBuilder
pub fn into_builder(self) -> DeviceInfoBuilder
Converts a DeviceInfo into a DeviceInfoBuilder.