pub struct GraphicsPipelineInfo {
pub alpha_to_coverage: bool,
pub alpha_to_one: bool,
pub bindless_descriptor_count: u32,
pub blend: BlendInfo,
pub cull_mode: CullModeFlags,
pub front_face: FrontFace,
pub min_sample_shading: Option<OrderedFloat<f32>>,
pub polygon_mode: PolygonMode,
pub topology: PrimitiveTopology,
pub samples: SampleCount,
}Expand description
Information used to create a GraphicsPipeline instance.
Fields
alpha_to_coverage: boolControls whether a temporary coverage value is generated based on the alpha component of the fragment’s first color output.
alpha_to_one: boolControls whether the alpha component of the fragment’s first color output is replaced with one.
bindless_descriptor_count: u32The number of descriptors to allocate for a given binding when using bindless (unbounded) syntax.
The default is 8192.
Examples
Basic usage (GLSL):
#version 460 core
#extension GL_EXT_nonuniform_qualifier : require
#pragma shader_stage(fragment)
layout(set = 0, binding = 0) uniform sampler2D my_binding[];
void main() {
// my_binding will have space for 8,192 images by default
}blend: BlendInfoSpecifies color blend state used when rasterization is enabled for any color attachments accessed during rendering.
The default value is BlendInfo::REPLACE.
cull_mode: CullModeFlagsBitmask controlling triangle culling.
The default value is vk::CullModeFlags::BACK.
front_face: FrontFaceInterprets polygon front-facing orientation.
The default value is vk::FrontFace::COUNTER_CLOCKWISE.
min_sample_shading: Option<OrderedFloat<f32>>Specifies a fraction of the minimum number of unique samples to process for each fragment.
polygon_mode: PolygonModeControls polygon rasterization mode.
The default value is vk::PolygonMode::FILL.
topology: PrimitiveTopologyInput primitive topology.
The default value is vk::PrimitiveTopology::TRIANGLE_LIST.
samples: SampleCountMultisampling antialias mode.
The default value is SampleCount::Type1.
Implementations
Sourceimpl GraphicsPipelineInfo
impl GraphicsPipelineInfo
Sourcepub fn builder() -> GraphicsPipelineInfoBuilder
pub fn builder() -> GraphicsPipelineInfoBuilder
Creates a default GraphicsPipelineInfoBuilder.
Sourcepub fn into_builder(self) -> GraphicsPipelineInfoBuilder
pub fn into_builder(self) -> GraphicsPipelineInfoBuilder
Converts a GraphicsPipelineInfo into a GraphicsPipelineInfoBuilder.