GraphicsPipelineInfoBuilder

Struct GraphicsPipelineInfoBuilder 

pub struct GraphicsPipelineInfoBuilder { /* private fields */ }
Builder for GraphicsPipelineInfo.

Implementations

Source

impl GraphicsPipelineInfoBuilder

pub fn alpha_to_coverage(self, value: bool) -> Self

Controls whether a temporary coverage value is generated based on the alpha component of the fragment’s first color output.

pub fn alpha_to_one(self, value: bool) -> Self

Controls whether the alpha component of the fragment’s first color output is replaced with one.

pub fn bindless_descriptor_count(self, value: u32) -> Self

The number of descriptors to allocate for a given binding when using bindless (unbounded) syntax.

The default is 8192.

Examples

Basic usage (GLSL):

#version 460 core
#extension GL_EXT_nonuniform_qualifier : require
#pragma shader_stage(fragment)

layout(set = 0, binding = 0) uniform sampler2D my_binding[];

void main() {
    // my_binding will have space for 8,192 images by default
}
pub fn blend(self, value: BlendInfo) -> Self

Specifies color blend state used when rasterization is enabled for any color attachments accessed during rendering.

The default value is BlendInfo::REPLACE.

pub fn cull_mode(self, value: CullModeFlags) -> Self

Bitmask controlling triangle culling.

The default value is vk::CullModeFlags::BACK.

pub fn front_face(self, value: FrontFace) -> Self

Interprets polygon front-facing orientation.

The default value is vk::FrontFace::COUNTER_CLOCKWISE.

pub fn min_sample_shading<VALUE: Into<OrderedFloat<f32>>>( self, value: VALUE, ) -> Self

Specifies a fraction of the minimum number of unique samples to process for each fragment.

pub fn polygon_mode(self, value: PolygonMode) -> Self

Controls polygon rasterization mode.

The default value is vk::PolygonMode::FILL.

pub fn topology(self, value: PrimitiveTopology) -> Self

Input primitive topology.

The default value is vk::PrimitiveTopology::TRIANGLE_LIST.

pub fn samples(self, value: SampleCount) -> Self

Multisampling antialias mode.

The default value is SampleCount::Type1.

See VkPipelineMultisampleStateCreateInfo.

Source

impl GraphicsPipelineInfoBuilder

pub fn build(self) -> GraphicsPipelineInfo

Builds a new GraphicsPipelineInfo.