pub struct ImageInfo {
pub array_layer_count: u32,
pub dedicated: bool,
pub depth: u32,
pub flags: ImageCreateFlags,
pub fmt: Format,
pub height: u32,
pub mip_level_count: u32,
pub sample_count: SampleCount,
pub tiling: ImageTiling,
pub ty: ImageType,
pub usage: ImageUsageFlags,
pub width: u32,
}Expand description
Information used to create an Image instance.
Fields
array_layer_count: u32The number of layers in the image.
dedicated: boolSpecifies a dedicated memory allocation managed by the Vulkan driver and not by the internal memory allocation pool transient resources share.
The driver may optimize access to dedicated buffers.
depth: u32Image extent of the Z axis, when describing a three dimensional image.
flags: ImageCreateFlagsA bitmask of describing additional parameters of the image.
fmt: FormatThe format and type of the texel blocks that will be contained in the image.
height: u32Image extent of the Y axis, when describing a two or three dimensional image.
mip_level_count: u32The number of levels of detail available for minified sampling of the image.
sample_count: SampleCountSpecifies the number of [samples per texel].
See VkImageCreateInfo.
tiling: ImageTilingSpecifies the tiling arrangement of the texel blocks in memory.
The default value is vk::ImageTiling::OPTIMAL.
ty: ImageTypeThe basic dimensionality of the image.
Layers in array textures do not count as a dimension for the purposes of the image type.
usage: ImageUsageFlagsA bitmask of describing the intended usage of the image.
width: u32Image extent of the X axis.
Implementations
Sourceimpl ImageInfo
impl ImageInfo
Sourcepub const fn cube(size: u32, fmt: Format, usage: ImageUsageFlags) -> ImageInfo
pub const fn cube(size: u32, fmt: Format, usage: ImageUsageFlags) -> ImageInfo
Specifies a cube image.
Sourcepub const fn image_1d(
size: u32,
fmt: Format,
usage: ImageUsageFlags,
) -> ImageInfo
pub const fn image_1d( size: u32, fmt: Format, usage: ImageUsageFlags, ) -> ImageInfo
Specifies a one-dimensional image.
Sourcepub const fn image_2d(
width: u32,
height: u32,
fmt: Format,
usage: ImageUsageFlags,
) -> ImageInfo
pub const fn image_2d( width: u32, height: u32, fmt: Format, usage: ImageUsageFlags, ) -> ImageInfo
Specifies a two-dimensional image.
Sourcepub const fn image_2d_array(
width: u32,
height: u32,
array_elements: u32,
fmt: Format,
usage: ImageUsageFlags,
) -> ImageInfo
pub const fn image_2d_array( width: u32, height: u32, array_elements: u32, fmt: Format, usage: ImageUsageFlags, ) -> ImageInfo
Specifies a two-dimensional image array.
Sourcepub const fn image_3d(
width: u32,
height: u32,
depth: u32,
fmt: Format,
usage: ImageUsageFlags,
) -> ImageInfo
pub const fn image_3d( width: u32, height: u32, depth: u32, fmt: Format, usage: ImageUsageFlags, ) -> ImageInfo
Specifies a three-dimensional image.
Sourcepub fn builder() -> ImageInfoBuilder
pub fn builder() -> ImageInfoBuilder
Creates a default ImageInfoBuilder.
Sourcepub fn into_image_view(self) -> ImageViewInfo
pub fn into_image_view(self) -> ImageViewInfo
Provides an ImageViewInfo for this format, type, aspect, array elements, and mip levels.
Sourcepub fn is_cube_array(self) -> bool
pub fn is_cube_array(self) -> bool
Returns true if this image is a cube array
Sourcepub fn into_builder(self) -> ImageInfoBuilder
pub fn into_builder(self) -> ImageInfoBuilder
Converts an ImageInfo into an ImageInfoBuilder.