pub struct ImageInfoBuilder { /* private fields */ }Expand description
Builder for ImageInfo.
Implementations
Sourceimpl ImageInfoBuilder
impl ImageInfoBuilder
Sourcepub fn alloc_dedicated(self, value: bool) -> Self
pub fn alloc_dedicated(self, value: bool) -> Self
Specifies a dedicated memory allocation managed by the Vulkan driver and not by the internal memory allocation pool transient resources share.
The driver may optimize access to dedicated images.
Sourcepub fn array_layer_count(self, value: u32) -> Self
pub fn array_layer_count(self, value: u32) -> Self
The number of layers in the image.
Sourcepub fn depth(self, value: u32) -> Self
pub fn depth(self, value: u32) -> Self
Image extent of the Z axis, when describing a three dimensional image.
Sourcepub fn flags(self, value: ImageCreateFlags) -> Self
pub fn flags(self, value: ImageCreateFlags) -> Self
A bitmask describing additional parameters of the image.
Sourcepub fn format(self, value: Format) -> Self
pub fn format(self, value: Format) -> Self
The format and type of the texel blocks that will be contained in the image.
Sourcepub fn height(self, value: u32) -> Self
pub fn height(self, value: u32) -> Self
Image extent of the Y axis, when describing a two or three dimensional image.
Sourcepub fn host_readable(self, value: bool) -> Self
pub fn host_readable(self, value: bool) -> Self
Specifies an image whose memory is host-visible and may be mapped for reads.
Memory optimal for CPU readback of data may be used.
Sourcepub fn host_writable(self, value: bool) -> Self
pub fn host_writable(self, value: bool) -> Self
Specifies an image whose memory is host-visible and may be mapped for writes.
Memory optimal for uploading data to the GPU may be used.
Sourcepub fn mip_level_count(self, value: u32) -> Self
pub fn mip_level_count(self, value: u32) -> Self
The number of levels of detail available for minified sampling of the image.
Sourcepub fn sample_count(self, value: SampleCount) -> Self
pub fn sample_count(self, value: SampleCount) -> Self
Specifies the number of [samples per texel].
See VkImageCreateInfo.
Sourcepub fn sharing_mode(self, value: SharingMode) -> Self
pub fn sharing_mode(self, value: SharingMode) -> Self
Controls whether the image is accessible from a single queue family (EXCLUSIVE) or from
multiple queue families concurrently (CONCURRENT).
EXCLUSIVE (the default) restricts the image to a single queue family. This may enable
driver optimizations but requires ownership transfers to use the image on a different queue
family.
Set to CONCURRENT when the image will be accessed from multiple queue families (e.g.
graphics and compute on separate queues).
See
VkSharingMode
in the Vulkan specification.
Sourcepub fn tiling(self, value: ImageTiling) -> Self
pub fn tiling(self, value: ImageTiling) -> Self
Specifies the tiling arrangement of the texel blocks in memory.
The default value is vk::ImageTiling::OPTIMAL.
Sourcepub fn image_type(self, value: ImageType) -> Self
pub fn image_type(self, value: ImageType) -> Self
The basic dimensionality of the image.
Layers in array textures do not count as a dimension for the purposes of the image type.
Sourcepub fn usage(self, value: ImageUsageFlags) -> Self
pub fn usage(self, value: ImageUsageFlags) -> Self
A bitmask describing the intended usage of the image.
See VkImageUsageFlagBits.
Sourceimpl ImageInfoBuilder
impl ImageInfoBuilder
Sourcepub fn into_image_view(self) -> ImageViewInfoBuilder
pub fn into_image_view(self) -> ImageViewInfoBuilder
Provides an ImageViewInfo for this format, type, aspect, array elements, and mip levels.