InstanceInfo

Struct InstanceInfo 

pub struct InstanceInfo {
    pub api_version: ApiVersion,
    pub debug: bool,
    pub extension_names: &'static [&'static CStr],
}
Information used to create an Instance instance.

Fields

api_version: ApiVersion

The Vulkan API version to target.

debug: bool

Enables Vulkan validation layers.

This requires a Vulkan SDK installation and will cause validation errors to introduce panics as they happen.

Set VK_GRAPH_SKIP_VALIDATION_PARK=1 to keep logging validation errors without parking the callback thread for debugger attach.

NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will throw an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.

Platform-specific

macOS: Has no effect unless the loaded feature is enabled.

extension_names: &'static [&'static CStr]

Required Vulkan instance extension names to load.

Implementations

Source

impl InstanceInfo

pub fn builder() -> InstanceInfoBuilder

Creates a default InstanceInfoBuilder.

pub fn into_builder(self) -> InstanceInfoBuilder

Converts a InstanceInfo into a InstanceInfoBuilder.