pub struct InstanceInfoBuilder { /* private fields */ }Expand description
Builder for InstanceInfo.
Implementations
Sourceimpl InstanceInfoBuilder
impl InstanceInfoBuilder
Sourcepub fn api_version(self, value: ApiVersion) -> Self
pub fn api_version(self, value: ApiVersion) -> Self
The Vulkan API version to target.
Defaults to Instance::DEFAULT_API_VERSION.
Sourcepub fn debug(self, value: bool) -> Self
pub fn debug(self, value: bool) -> Self
Enables Vulkan validation layers.
This requires a Vulkan SDK installation and will panic when validation errors happen. Additionally, the device must support VK_EXT_private_data.
When stderr is attached to an interactive terminal, validation errors will park the
callback thread for debugger attach.
Set VK_GRAPH_SKIP_VALIDATION_PARK=1 to keep logging validation errors without parking.
NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will report an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.
Platform-specific
macOS: Has no effect unless the loaded feature is enabled.
Sourcepub fn extension_names(self, value: &'static [&'static CStr]) -> Self
pub fn extension_names(self, value: &'static [&'static CStr]) -> Self
Required Vulkan instance extension names to load.
Sourceimpl InstanceInfoBuilder
impl InstanceInfoBuilder
Sourcepub fn build(self) -> InstanceInfo
pub fn build(self) -> InstanceInfo
Builds a new InstanceInfo.