InstanceInfoBuilder

Struct InstanceInfoBuilder 

pub struct InstanceInfoBuilder { /* private fields */ }
Builder for InstanceInfo.

Implementations

Source

impl InstanceInfoBuilder

pub fn api_version(self, value: ApiVersion) -> Self

The Vulkan API version to target.

pub fn debug(self, value: bool) -> Self

Enables Vulkan validation layers.

This requires a Vulkan SDK installation and will cause validation errors to introduce panics as they happen.

Set VK_GRAPH_SKIP_VALIDATION_PARK=1 to keep logging validation errors without parking the callback thread for debugger attach.

NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will throw an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.

Platform-specific

macOS: Has no effect unless the loaded feature is enabled.

pub fn extension_names(self, value: &'static [&'static CStr]) -> Self

Required Vulkan instance extension names to load.

Source

impl InstanceInfoBuilder

pub fn build(self) -> InstanceInfo

Builds a new InstanceInfo.