pub struct InstanceInfoBuilder { /* private fields */ }Expand description
Builder for InstanceInfo.
Implementations
Sourceimpl InstanceInfoBuilder
impl InstanceInfoBuilder
Sourcepub fn api_version(self, value: ApiVersion) -> Self
pub fn api_version(self, value: ApiVersion) -> Self
The Vulkan API version to target.
Sourcepub fn debug(self, value: bool) -> Self
pub fn debug(self, value: bool) -> Self
Enables Vulkan validation layers.
This requires a Vulkan SDK installation and will cause validation errors to introduce panics as they happen.
Set VK_GRAPH_SKIP_VALIDATION_PARK=1 to keep logging validation errors without parking the
callback thread for debugger attach.
NOTE: Consider turning OFF debug if you discover an unknown issue. Often the validation layers will throw an error before other layers can provide additional context such as the API dump info or other messages. You might find the “actual” issue is detailed in those subsequent details.
Platform-specific
macOS: Has no effect unless the loaded feature is enabled.
Sourcepub fn extension_names(self, value: &'static [&'static CStr]) -> Self
pub fn extension_names(self, value: &'static [&'static CStr]) -> Self
Required Vulkan instance extension names to load.
Sourceimpl InstanceInfoBuilder
impl InstanceInfoBuilder
Sourcepub fn build(self) -> InstanceInfo
pub fn build(self) -> InstanceInfo
Builds a new InstanceInfo.