pub enum PresentResult {
QueuedOptimal,
QueuedSuboptimal,
NotQueued(PresentError),
}Expand description
Result of one image in a queue presentation batch.
Variants
QueuedOptimal
The image was queued and the swapchain remained optimal.
QueuedSuboptimal
The image was queued, but the swapchain should be recreated soon.
NotQueued(PresentError)
The image was not queued for presentation.
Implementations
Sourceimpl PresentResult
impl PresentResult