LazyPool

Struct LazyPool 

pub struct LazyPool {
    pub device: Device,
    pub info: PoolConfig,
    /* private fields */
}
A balanced resource allocator.

The information for each resource request is compared against the stored resources for compatibility. If no acceptable resources are stored for the information provided a new resource is created and returned.

Details

  • Acceleration structures may be larger than requested
  • Buffers may be larger than requested or have additional usage flags
  • Images may have additional usage flags

Bucket Strategy

The information for each resource request is the key for a HashMap of buckets. If no bucket exists with compatible information a new bucket is created.

In practice this means that for a PoolConfig::image_capacity of 4, requests for a 1024x1024 image with certain attributes will store a maximum of 4 such images. Requests for any image having a different size or incompatible attributes will store an additional maximum of 4 images.

Memory Management

If requests for varying resources are common LazyPool::clear_images_by_info and other memory management functions are necessary in order to avoid using all available device memory.

Fields

device: Device

The device which owns this pool.

Note: This field is read-only.

info: PoolConfig

Information used to create this pool.

Note: This field is read-only.

Implementations

Source

impl LazyPool

pub fn new(device: &Device) -> Self

Constructs a new LazyPool.

pub fn with_capacity(device: &Device, info: impl Into<PoolConfig>) -> Self

Constructs a new LazyPool with the given capacity information.

pub fn clear(&mut self)

Clears the pool, removing all resources.

pub fn clear_accel_structs(&mut self)

Clears the pool of acceleration structure resources.

pub fn clear_accel_structs_by_type( &mut self, accel_struct_ty: AccelerationStructureTypeKHR, )

Clears the pool of all acceleration structure resources matching the given type.

pub fn clear_buffers(&mut self)

Clears the pool of buffer resources.

pub fn clear_images(&mut self)

Clears the pool of image resources.

pub fn clear_images_by_info(&mut self, info: impl Into<ImageInfo>)

Clears the pool of image resources matching the given information.

pub fn retain_accel_structs<F>(&mut self, f: F)

Retains only the acceleration structure resources specified by the predicate.

In other words, remove all resources for which f(vk::AccelerationStructureTypeKHR) returns false.

The elements are visited in unsorted (and unspecified) order.

Performance

Provides the same performance guarantees as HashMap::retain.