pub struct PoolConfig {
pub accel_struct_capacity: usize,
pub buffer_capacity: usize,
pub image_capacity: usize,
}Fields
accel_struct_capacity: usizeThe maximum size of a single bucket of acceleration structure resource instances. The
default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored acceleration structure instances.
buffer_capacity: usizeThe maximum size of a single bucket of buffer resource instances. The default value is
PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored buffer instances.
image_capacity: usizeThe maximum size of a single bucket of image resource instances. The default value is
PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored image instances.
Implementations
Sourceimpl PoolConfig
impl PoolConfig
Sourcepub const DEFAULT_RESOURCE_CAPACITY: usize = 16
pub const DEFAULT_RESOURCE_CAPACITY: usize = 16
The maximum size of a single bucket of resource instances.
Sourcepub fn builder() -> PoolConfigBuilder
pub fn builder() -> PoolConfigBuilder
Creates a default PoolConfigBuilder.
Sourcepub fn into_builder(self) -> PoolConfigBuilder
pub fn into_builder(self) -> PoolConfigBuilder
Converts a PoolConfig into a PoolConfigBuilder.
Sourcepub const fn with_capacity(resource_capacity: usize) -> Self
pub const fn with_capacity(resource_capacity: usize) -> Self
Constructs a new PoolConfig with the given acceleration structure, buffer and image
resource capacity for any single bucket.