pub struct PoolConfigBuilder { /* private fields */ }Expand description
Builder for PoolConfig.
Implementations
Sourceimpl PoolConfigBuilder
impl PoolConfigBuilder
Sourcepub fn accel_struct_capacity(self, value: usize) -> Self
pub fn accel_struct_capacity(self, value: usize) -> Self
The maximum size of a single bucket of acceleration structure resource instances. The
default value is PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored acceleration structure instances.
Sourcepub fn buffer_capacity(self, value: usize) -> Self
pub fn buffer_capacity(self, value: usize) -> Self
The maximum size of a single bucket of buffer resource instances. The default value is
PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored buffer instances.
Sourcepub fn image_capacity(self, value: usize) -> Self
pub fn image_capacity(self, value: usize) -> Self
The maximum size of a single bucket of image resource instances. The default value is
PoolConfig::DEFAULT_RESOURCE_CAPACITY.
Note
Individual Pool implementations store varying numbers of buckets. Read the
documentation of each implementation to understand how this affects total number of
stored image instances.
Sourceimpl PoolConfigBuilder
impl PoolConfigBuilder
Sourcepub fn build(self) -> PoolConfig
pub fn build(self) -> PoolConfig
Builds a new PoolConfig.