pub struct CommandStreamRun<'a, A> { /* private fields */ }Expand description
An in-progress invocation of a CommandStream into a Graph.
Bind every declared stream argument before calling CommandStreamRun::finish.
Distinct stream arguments must bind to distinct parent-graph nodes.
let stream = CommandStream::finalize(|stream| {
stream.arg(ImageInfo::image_2d(
32,
32,
vk::Format::R8G8B8A8_UNORM,
vk::ImageUsageFlags::TRANSFER_DST,
))
})
.into_stream();
let mut graph = Graph::new();
graph
.insert_cmd_stream(&stream)
.with_arg(stream.args, image)
.finish();Implementations
Sourceimpl<'a, A> CommandStreamRun<'a, A>
impl<'a, A> CommandStreamRun<'a, A>
Sourcepub fn with_arg<T, N>(self, arg: StreamArg<T>, node: N) -> Selfwhere
N: StreamArgBindable<T>,
pub fn with_arg<T, N>(self, arg: StreamArg<T>, node: N) -> Selfwhere
N: StreamArgBindable<T>,
Sets a stream argument to a graph node for this invocation.
The same argument may be rebound, but distinct arguments cannot bind to the same parent node. Stream scheduling and resource ownership tracking use node identity.
Panics
Panics if another argument is already bound to node.