CommandStreamRun

Struct CommandStreamRun 

pub struct CommandStreamRun<'a, A> { /* private fields */ }
An in-progress invocation of a CommandStream into a Graph.

Bind every declared stream argument before calling CommandStreamRun::finish.

let stream = CommandStream::finalize(|stream| {
    stream.arg(ImageInfo::image_2d(
        32,
        32,
        vk::Format::R8G8B8A8_UNORM,
        vk::ImageUsageFlags::TRANSFER_DST,
    ))
})
.into_stream();

let mut graph = Graph::new();
graph
    .insert_cmd_stream(&stream)
    .with_arg(stream.args, image)
    .finish();

Implementations

Source

impl<'a, A> CommandStreamRun<'a, A>

pub fn with_arg<T, N>(self, arg: StreamArg<T>, node: N) -> Self
where N: StreamArgBindable<T>,

Sets a stream argument to a graph node for this invocation.

pub fn finish(self) -> &'a mut Graph

Finishes this stream invocation and returns to the parent graph.