pub struct StreamCommand<'a> { /* private fields */ }Expand description
A command being recorded into a CommandStreamMut.
let stream = CommandStream::finalize(|stream| {
stream
.begin_cmd()
.debug_name("stream command")
.record_cmd(|cmd| {
let _ = cmd;
});
})
.into_stream();Implementations
Sourceimpl<'a> StreamCommand<'a>
impl<'a> StreamCommand<'a>
Sourcepub fn bind_resource<R>(&mut self, resource: R) -> R::Nodewhere
R: Resource,
pub fn bind_resource<R>(&mut self, resource: R) -> R::Nodewhere
R: Resource,
Stream equivalent of Command::bind_resource.
Sourcepub fn bind_pipeline<P>(self, pipeline: P) -> P::Commandwhere
P: StreamPipeline<'a>,
pub fn bind_pipeline<P>(self, pipeline: P) -> P::Commandwhere
P: StreamPipeline<'a>,
Stream equivalent of Command::bind_pipeline.
Sourcepub fn debug_name(self, name: impl Into<String>) -> Self
pub fn debug_name(self, name: impl Into<String>) -> Self
Stream equivalent of Command::debug_name.
Sourcepub fn record_cmd(
self,
func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static,
) -> Self
pub fn record_cmd( self, func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static, ) -> Self
Stream equivalent of Command::record_cmd.
Unlike graph commands, stream callbacks must be reusable and therefore implement
Fn + Send + Sync + 'static.
Sourcepub fn record_cmd_mut(
&mut self,
func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static,
)
pub fn record_cmd_mut( &mut self, func: impl for<'r> Fn(CommandRef<'r>) + Send + Sync + 'static, )
Mutable-borrow stream equivalent of Command::record_cmd.
Unlike graph commands, stream callbacks must be reusable and therefore implement
Fn + Send + Sync + 'static.
Sourcepub fn resource_access<N>(self, resource_node: N, access: AccessType) -> Self
pub fn resource_access<N>(self, resource_node: N, access: AccessType) -> Self
Stream equivalent of Command::resource_access.
Sourcepub fn set_resource_access<N>(&mut self, resource_node: N, access: AccessType)
pub fn set_resource_access<N>(&mut self, resource_node: N, access: AccessType)
Mutable-borrow stream equivalent of Command::resource_access.