GraphBuilder

Struct GraphBuilder 

pub struct GraphBuilder { /* private fields */ }
Builder for incrementally constructing a Graph.

Implementations

Source

impl GraphBuilder

pub fn new() -> Self

Creates an empty graph builder.

pub fn build(self) -> Graph

Builds the graph.

pub fn bind_resource<R>(&mut self, resource: R) -> R::Node
where R: Resource,

Binds a Vulkan buffer, image, or acceleration structure resource to this graph.

pub fn blit_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, filter: Filter, ) -> Self

Copies an image, potentially performing format conversion.

pub fn clear_color_image( self, image: impl Into<AnyImageNode>, color: impl Into<ClearColorValue>, ) -> Self

Clears a color image.

pub fn clear_depth_stencil_image( self, image: impl Into<AnyImageNode>, depth: f32, stencil: u32, ) -> Self

Clears a depth/stencil image.

pub fn copy_buffer( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyBufferNode>, ) -> Self

Copies data between buffers.

pub fn copy_buffer_to_image( self, src: impl Into<AnyBufferNode>, dst: impl Into<AnyImageNode>, ) -> Self

Copies data from a buffer into an image.

pub fn copy_image( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyImageNode>, ) -> Self

Copies all layers of a source image to a destination image.

pub fn copy_image_to_buffer( self, src: impl Into<AnyImageNode>, dst: impl Into<AnyBufferNode>, ) -> Self

Copies image data into a buffer.

pub fn fill_buffer( self, buffer: impl Into<AnyBufferNode>, region: Range<DeviceSize>, data: u32, ) -> Self

Fills a region of a buffer with a fixed value.

pub fn update_buffer( self, buffer: impl Into<AnyBufferNode>, offset: DeviceSize, data: impl AsRef<[u8]> + 'static + Send, ) -> Self

Records a vkCmdUpdateBuffer command.